/*******************************************************************************
 * FILENAME: AutoDocs.c
 *
 * PROJECT:
 *    Bitty HTTP
 *
 * FILE DESCRIPTION:
 *    
 *
 * COPYRIGHT:
 *    Copyright (c) 2019 Paul Hutchinson
 *
 *    Permission is hereby granted, free of charge, to any person obtaining a copy
 *    of this software and associated documentation files (the "Software"), to deal
 *    in the Software without restriction, including without limitation the rights
 *    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *    copies of the Software, and to permit persons to whom the Software is
 *    furnished to do so, subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included in all
 *    copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *    SOFTWARE.
 *
 ******************************************************************************/

/*** HEADER FILES TO INCLUDE  ***/
#include "Pages/Pages.h"
#include "Common/Headers.h"

/*** DEFINES                  ***/

/*** MACROS                   ***/

/*** TYPE DEFINITIONS         ***/

/*** FUNCTION PROTOTYPES      ***/

/*** VARIABLE DEFINITIONS     ***/

const char m_AutoDocsHTML[]=
"<h1><span>1</span>"PRODUCTNAME" Autodocs</h1>\n"
"<div class='Autodoc'>"
"<table class='TOC'>\n"
"<tr>   <td class='TOCHeader'>W</td></tr><tr><td><a href=\"#WS_COOKIE_WebServer.c\">WS_COOKIE</a></td></tr>\n"
"<tr><td><a href=\"#WS_GET_WebServer.c\">WS_GET</a></td></tr>\n"
"<tr><td><a href=\"#WS_GetOSSocketHandles_WebServer.c\">WS_GetOSSocketHandles</a></td></tr>\n"
"<tr><td><a href=\"#WS_Header_WebServer.c\">WS_Header</a></td></tr>\n"
"<tr><td><a href=\"#WS_Init_WebServer.c\">WS_Init</a></td></tr>\n"
"<tr><td><a href=\"#WS_Location_WebServer.c\">WS_Location</a></td></tr>\n"
"<tr><td><a href=\"#WS_POST_WebServer.c\">WS_POST</a></td></tr>\n"
"<tr><td><a href=\"#WS_SetCookie_WebServer.c\">WS_SetCookie</a></td></tr>\n"
"<tr><td><a href=\"#WS_SetHTTPStatusCode_WebServer.c\">WS_SetHTTPStatusCode</a></td></tr>\n"
"<tr><td><a href=\"#WS_Shutdown_WebServer.c\">WS_Shutdown</a></td></tr>\n"
"<tr><td><a href=\"#WS_Start_WebServer.c\">WS_Start</a></td></tr>\n"
"<tr><td><a href=\"#WS_Tick_WebServer.c\">WS_Tick</a></td></tr>\n"
"<tr><td><a href=\"#WS_URLDecode_WebServer.c\">WS_URLDecode</a></td></tr>\n"
"<tr><td><a href=\"#WS_URLDecodeInPlace_WebServer.c\">WS_URLDecodeInPlace</a></td></tr>\n"
"<tr><td><a href=\"#WS_URLEncode_WebServer.c\">WS_URLEncode</a></td></tr>\n"
"<tr><td><a href=\"#WS_WriteChunk_WebServer.c\">WS_WriteChunk</a></td></tr>\n"
"<tr><td><a href=\"#WS_WriteChunkStr_WebServer.c\">WS_WriteChunkStr</a></td></tr>\n"
"<tr><td><a href=\"#WS_WriteWhole_WebServer.c\">WS_WriteWhole</a></td></tr>\n"
"<tr><td><a href=\"#WS_WriteWholeStr_WebServer.c\">WS_WriteWholeStr</a></td></tr>\n"
"</table>\n"
"<BR><HR>\n"
"<a name=\"WS_COOKIE_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_COOKIE()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_COOKIE\n"
"\n"
" SYNOPSIS:\n"
"    const char *WS_COOKIE(struct WebServer *Web,const char *Arg);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Arg [I] -- The GET argument to search for an return\n"
"\n"
" FUNCTION:\n"
"    This function gets a COOKIE from the request and returns it.\n"
"\n"
"    You must place all the COOKIE names you are going to be using (or could\n"
"    want to use) in the Web-&gt;PageProp-&gt;Cookies[] array for the system to be\n"
"    able read a cookie.\n"
"\n"
" RETURNS:\n"
"    A pointer to the value or NULL if was not set.\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_GET_WebServer.c\">WS_GET()</a>, <a href=\"#WS_POST_WebServer.c\">WS_POST()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_GET_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_GET()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_GET\n"
"\n"
" SYNOPSIS:\n"
"    const char *WS_GET(struct WebServer *Web,const char *Arg);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Arg [I] -- The GET argument to search for an return\n"
"\n"
" FUNCTION:\n"
"    This function gets a GET arg from the request and returns it.\n"
"\n"
"    You must place all the GET args you are going to be using (or could want\n"
"    to use) in the Web-&gt;PageProp-&gt;Gets[] array for the system to be able\n"
"    read a GET arg.\n"
"\n"
" RETURNS:\n"
"    A pointer to the value or NULL if was not set.\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_COOKIE_WebServer.c\">WS_COOKIE()</a>, <a href=\"#WS_POST_WebServer.c\">WS_POST()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_GetOSSocketHandles_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_GetOSSocketHandles()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_GetOSSocketHandles\n"
"\n"
" SYNOPSIS:\n"
"    int WS_GetOSSocketHandles(t_ConSocketHandle *Handles);\n"
"\n"
" PARAMETERS:\n"
"    Handles [O] -- An array to fill in with the handles being used by the\n"
"                   web server.  This must be at least\n"
"                   'WS_OPT_MAX_CONNECTIONS+1' in size.\n"
"\n"
" FUNCTION:\n"
"    This function gets all the socket handles being used by the web server.\n"
"    You can use these handles to wait on.\n"
"\n"
"    The returned handles depend on what 't_ConSocketHandle' is defined as.\n"
"\n"
" RETURNS:\n"
"    The number of handles being returned\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Header_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Header()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Header\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_Header(struct WebServer *Web,const char *Header);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Header [I] -- The header to write.\n"
"\n"
" FUNCTION:\n"
"    This function writes out a header as part of the http reply.\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- There was an error (have you already started sending content?)\n"
"\n"
" NOTES:\n"
"    You do not need to end the string with a \\r\\n.  This function adds it\n"
"    for you.\n"
"\n"
" LIMITATIONS:\n"
"    You can not use this function if you have started sending content.\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_WriteChunk_WebServer.c\">WS_WriteChunk()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Init_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Init()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Init\n"
"\n"
" SYNOPSIS:\n"
"    void WS_Init(void);\n"
"\n"
" PARAMETERS:\n"
"    NONE\n"
"\n"
" FUNCTION:\n"
"    This function init's the web server.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Shutdown_WebServer.c\">WS_Shutdown()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Location_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Location()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Location\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_Location(struct WebServer *Web,const char *NewURL);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    NewURL [I] -- The new URL to redirect the browser to.\n"
"\n"
" FUNCTION:\n"
"    This function does a 301 Moved Permanently redirect.\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- There was an error\n"
"\n"
" NOTES:\n"
"    This must be done before anything else is sent (content, header, etc)\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_POST_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_POST()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_POST\n"
"\n"
" SYNOPSIS:\n"
"    const char *WS_POST(struct WebServer *Web,const char *Arg);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Arg [I] -- The GET argument to search for an return\n"
"\n"
" FUNCTION:\n"
"    This function gets a POST arg from the request and returns it.\n"
"\n"
"    You must place all the POST args you are going to be using (or could\n"
"    want to use) in the Web-&gt;PageProp-&gt;Posts[] array for the system to be\n"
"    able read a POST arg.\n"
"\n"
" RETURNS:\n"
"    A pointer to the value or NULL if was not set.\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_GET_WebServer.c\">WS_GET()</a>, <a href=\"#WS_COOKIE_WebServer.c\">WS_COOKIE()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_SetCookie_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_SetCookie()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_SetCookie\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_SetCookie(struct WebServer *Web,const char *Name,\n"
"          const char *Value,time_t Expire,const char *Path,const char *Domain,\n"
"          bool Secure,bool HttpOnly);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Name [I] -- Name of the cookie.  This can not have ' ', ',', or ';'.\n"
"    Value [I] -- The value of the cookie. This value is stored on the clients\n"
"                 computer; do not store sensitive information.  This is also\n"
"                 not escaped (or URI encoded).  You can not have the chars\n"
"                 ';', '=', '\\r', '\\n', ' ', or ','.  Short answer, URI encode\n"
"                 your string (WS_URLEncode).\n"
"    Expire [I] -- The time the cookie expires.  This is a time_t\n"
"                  (Unix timestamp) so is in number of seconds since the epoch.\n"
"                  This is sent into gmtime() to make a string.  Pass 0 to\n"
"                  ignore.\n"
"    Path [I] -- The path on the server in which the cookie will be available\n"
"                on. If set to '/', the cookie will be available within the\n"
"                entire domain. If set to '/foo/', the cookie will only be\n"
"                available within the /foo/ directory and all sub-directories\n"
"                such as /foo/bar/ of domain.  If you pass NULL the current\n"
"                directory that the cookie is being set in.\n"
"    Domain [I] -- The (sub)domain that the cookie is available to. Setting\n"
"                  this to a subdomain (such as 'www.example.com') will make\n"
"                  the cookie available to that subdomain and all other\n"
"                  sub-domains of it (i.e. w2.www.example.com). To make\n"
"                  the cookie available to the whole domain (including\n"
"                  all subdomains of it), simply set the value to the\n"
"                  domain name ('example.com', in this case).\n"
"\n"
"                  Older browsers still implementing the deprecated RFC 2109\n"
"                  may require a leading . to match all subdomains.\n"
"    Secure [I] -- Indicates that the cookie should only be transmitted over\n"
"                  a secure HTTPS connection from the client. When set to\n"
"                  true, the cookie will only be set if a secure connection\n"
"                  exists. On the server-side, it's on the programmer to\n"
"                  send this kind of cookie only on secure connection.\n"
"    HttpOnly [I] -- When true the cookie will be made accessible only\n"
"                    through the HTTP protocol. This means that the cookie\n"
"                    won't be accessible by scripting languages, such as\n"
"                    JavaScript. It has been suggested that this setting\n"
"                    can effectively help to reduce identity theft through\n"
"                    XSS attacks (although it is not supported by all\n"
"                    browsers), but that claim is often disputed.\n"
"\n"
" FUNCTION:\n"
"    This function sets a cookie to be sent to the client.\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- There was an error (have you already started sending content?)\n"
"\n"
" NOTES:\n"
"    Most of this header was taken from the PHP doc's.\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_SetHTTPStatusCode_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_SetHTTPStatusCode()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_SetHTTPStatusCode\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_SetHTTPStatusCode(struct WebServer *Web,e_ReplyStatusType Code);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Code [I] -- The status code to set.  Only a limited set are supported.\n"
"\n"
" FUNCTION:\n"
"    This function sets the http reply status code that is sent out.\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- There was an error\n"
"\n"
" NOTES:\n"
"    This must be done before anything else is sent (content, header, etc)\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Location_WebServer.c\">WS_Location()</a>, <a href=\"#WS_Header_WebServer.c\">WS_Header()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Shutdown_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Shutdown()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Shutdown\n"
"\n"
" SYNOPSIS:\n"
"    void WS_Shutdown(void);\n"
"\n"
" PARAMETERS:\n"
"    NONE\n"
"\n"
" FUNCTION:\n"
"    This function releases anything the web server is using.  After you\n"
"    call this you need to call WS_Init() again before you can use any\n"
"    web server functions.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Init_WebServer.c\">WS_Init()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Start_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Start()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Start\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_Start(uint16_t Port);\n"
"\n"
" PARAMETERS:\n"
"    Port [I] -- What port to listen on\n"
"\n"
" FUNCTION:\n"
"    This function starts the web server listening for incoming connections.\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- There was an error\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_WriteWhole_WebServer.c\">WS_WriteWhole()</a>, <a href=\"#WS_WriteChunk_WebServer.c\">WS_WriteChunk()</a>, <a href=\"#WS_Header_WebServer.c\">WS_Header()</a>,\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_Tick_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_Tick()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_Tick\n"
"\n"
" SYNOPSIS:\n"
"    void WS_Tick(void);\n"
"\n"
" PARAMETERS:\n"
"    NONE\n"
"\n"
" FUNCTION:\n"
"    This function runs the web server.  It accepts new connections, reads\n"
"    from existing connections, and sends data out of the open connections\n"
"    (it also handles timeouts).\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" NOTES:\n"
"    This must be called regularly.\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_URLDecode_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_URLDecode()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_URLDecode\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_URLDecode(const char *Value,char *Decoded,int MaxLen);\n"
"\n"
" PARAMETERS:\n"
"    Value [I] -- The string to decode.\n"
"    Decoded [O] -- The buffer to store the decoded string in.\n"
"    MaxLen [I] -- The size of 'Decoded'.\n"
"\n"
" FUNCTION:\n"
"    This function encodes a string into URL encoding (%20 for space)\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- If we had to clip the string to keep it in 'MaxLen'.\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_URLDecodeInPlace_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_URLDecodeInPlace()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_URLDecodeInPlace\n"
"\n"
" SYNOPSIS:\n"
"    char *WS_URLDecodeInPlace(char *Value);\n"
"\n"
" PARAMETERS:\n"
"    Value [I] -- The URL encoded string to decode\n"
"\n"
" FUNCTION:\n"
"    This function decodes a URL encoded string directly over top of the\n"
"    string.\n"
"\n"
" RETURNS:\n"
"    A pointer to the char directly after the new string ends (after the \\0)\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_URLEncode_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_URLEncode()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_URLEncode\n"
"\n"
" SYNOPSIS:\n"
"    bool WS_URLEncode(const char *Value,char *OutputBuffer,int MaxLen);\n"
"\n"
" PARAMETERS:\n"
"    Value [I] -- The string to encode.\n"
"    OutputBuffer [O] -- The buffer to store the encoded string in.  This\n"
"                        should be 3 times the size of Value for worst case.\n"
"    MaxLen [I] -- The size of 'OutputBuffer'.\n"
"\n"
" FUNCTION:\n"
"    This function encodes a string into URL encoding (%20 for space)\n"
"\n"
" RETURNS:\n"
"    true -- Things worked out\n"
"    false -- If we had to clip the string to keep it in 'MaxLen'.\n"
"\n"
" SEE ALSO:\n"
"    \n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_WriteChunk_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_WriteChunk()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_WriteChunk\n"
"\n"
" SYNOPSIS:\n"
"    void WS_WriteChunk(struct WebServer *Web,const char *Buffer,int Len);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Buffer [I] -- The buffer with the contents to send in it.\n"
"    Len [I] -- The number of bytes in 'Buffer'\n"
"\n"
" FUNCTION:\n"
"    This function sends content using the chunked method.  This means you\n"
"    do not need to know the length of the content before sending (you can\n"
"    build it as you go).\n"
"\n"
"    You would normally use this function for dynamic content.  That way\n"
"    you do not have to build the whole web page in a buffer before\n"
"    repling.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_WriteChunkStr_WebServer.c\">WS_WriteChunkStr()</a>, <a href=\"#WS_WriteWhole_WebServer.c\">WS_WriteWhole()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_WriteChunkStr_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_WriteChunkStr()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_WriteChunkStr\n"
"\n"
" SYNOPSIS:\n"
"    void WS_WriteChunkStr(struct WebServer *Web,const char *Buffer);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Buffer [I] -- The buffer with the contents to send in it.  This is\n"
"                  a C string (ending in \\0).\n"
"\n"
" FUNCTION:\n"
"    This function sends content using the chunked method.  This means you\n"
"    do not need to know the length of the content before sending (you can\n"
"    build it as you go).\n"
"\n"
"    This is the same as WS_WriteChunk() except it works on a C string\n"
"    instead of a buffer.  This function just calls WS_WriteChunk() with\n"
"    a strlen() for the length.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_WriteChunk_WebServer.c\">WS_WriteChunk()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_WriteWhole_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_WriteWhole()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_WriteWhole\n"
"\n"
" SYNOPSIS:\n"
"    void WS_WriteWhole(struct WebServer *Web,const char *Buffer,int Len);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Buffer [I] -- The buffer with the whole contents to send in it.\n"
"    Len [I] -- The number of bytes in 'Buffer'\n"
"\n"
" FUNCTION:\n"
"    This function sends the content to the client using 'Content-Length'.\n"
"    After you call this function you can not send any more content or headers.\n"
"\n"
"    You use this function if you are sending a static resource like a graphic\n"
"    or static web page.  You can also use this you have built all the content\n"
"    is a buffer and will not need to send any more.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_WriteWholeStr_WebServer.c\">WS_WriteWholeStr()</a>, <a href=\"#WS_WriteChunk_WebServer.c\">WS_WriteChunk()</a>\n"
"</pre>\n"
"</div>\n"
"<a href=\"#TOP\" class='HomeLink'>Index</a><a name=\"WS_WriteWholeStr_WebServer.c\"></a><h2 class='FunctionNameHeader'>WebServer.c/WS_WriteWholeStr()</h2>\n"
"<div class='FunctionProto'>\n"
"<pre> NAME:\n"
"    WS_WriteWholeStr\n"
"\n"
" SYNOPSIS:\n"
"    void WS_WriteWholeStr(struct WebServer *Web,const char *Buffer);\n"
"\n"
" PARAMETERS:\n"
"    Web [I] -- The web server context to work on\n"
"    Buffer [I] -- The buffer with the whole contents to send in it.  This\n"
"                  is a C string (ending in \\0).\n"
"\n"
" FUNCTION:\n"
"    This function sends the content to the client using 'Content-Length'.\n"
"    After you call this function you can not send any more content or headers.\n"
"\n"
"    This is the same as WS_WriteWhole() except it works on a C string\n"
"    instead of a buffer.  This function just calls WS_WriteWhole() with\n"
"    a strlen() for the length.\n"
"\n"
" RETURNS:\n"
"    NONE\n"
"\n"
" SEE ALSO:\n"
"    <a href=\"#WS_Start_WebServer.c\">WS_Start()</a>, <a href=\"#WS_WriteWhole_WebServer.c\">WS_WriteWhole()</a>\n"
"</pre>\n"
"</div>";

void File_AutoDocs(struct WebServer *Web)
{
    WS_WriteChunk(Web,m_AutoDocsHTML,sizeof(m_AutoDocsHTML)-1);
}
