/*******************************************************************************
 * FILENAME: Graphics.c
 *
 * PROJECT:
 *    Bitty HTTP
 *
 * FILE DESCRIPTION:
 *    
 *
 * COPYRIGHT:
 *    Copyright (c) 2019 Paul Hutchinson
 *
 *    Permission is hereby granted, free of charge, to any person obtaining a copy
 *    of this software and associated documentation files (the "Software"), to deal
 *    in the Software without restriction, including without limitation the rights
 *    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *    copies of the Software, and to permit persons to whom the Software is
 *    furnished to do so, subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included in all
 *    copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *    SOFTWARE.
 *
 ******************************************************************************/

/*** HEADER FILES TO INCLUDE  ***/
#include "CodeExamples.h"
#include "Pages/Pages.h"
#include "Common/Headers.h"

/*** DEFINES                  ***/

/*** MACROS                   ***/

/*** TYPE DEFINITIONS         ***/

/*** FUNCTION PROTOTYPES      ***/

/*** VARIABLE DEFINITIONS     ***/

const char m_GraphicsHTML[]=
"<h1><span>1</span>Graphics</h1>\n"
"<p>This example will show sending a static graphic (or any other file) with\n"
"a content type set to image/png. This continues the\n"
"<a href='/Doc/CSS.html'>CSS example</a>.</p>\n"
"\n"
"<h2>Files</h2>";

const char m_GraphicsHTML2[]=
"<h2>FileServer.c</h2>\n"
"<p>We update the file server file to have 1 new function that get called when\n"
"the graphic (\"/computer.png\" is requested.</p>\n"
"\n"
"<div class='code'>"
"void File_Root(struct WebServer *Web);\n"
"void File_SomeStyle(struct WebServer *Web);\n"
"void File_Quit(struct WebServer *Web);\n"
"void File_computer_png(struct WebServer *Web);\n"
"\n"
"struct FileInfo m_Files[]=\n"
"{\n"
"    /* Filename, Dynamic, Cookies, Gets, Posts, Callback */\n"
"    {\"/\",false,NULL,NULL,NULL,File_Root},\n"
"    {\"/SomeStyle.css\",false,NULL,NULL,NULL,File_SomeStyle},\n"
"    {\"/quit.html\",true,NULL,NULL,NULL,File_Quit},\n"
"    {\"/computer.png\",false,NULL,NULL,NULL,File_computer_png},\n"
"};\n"
"</div>\n"
"\n"
"<p>So we have added a line for the prototype to\n"
"<span class='coderef'>File_computer_png()</span> and a second line\n"
"for \"/computer.png\". This is the same as before.</p>\n"
"\n"
"<div class='code'>"
"const char RootHTML[]=\n"
"\"&lt;!DOCTYPE html&gt;\"\n"
"\"&lt;html&gt;\"\n"
"\"&lt;head&gt;\"\n"
"    \"&lt;title&gt;Bitty HTTP - Root&lt;/title&gt;\"\n"
"    \"&lt;link rel='stylesheet' href='/SomeStyle.css'&gt;\"\n"
"\"&lt;/head&gt;\"\n"
"\"&lt;body&gt;\"\n"
"    \"&lt;div id='top'&gt;Bitty HTTP Example - Root&lt;/div&gt;\"\n"
"    \"&lt;div id='quitbttn'&gt;&lt;a href='/quit.html'&gt;QUIT&lt;/a&gt;&lt;/div&gt;\"\n"
"    \"&lt;div id='content'&gt;\"\n"
"        \"Hello World with some style and now with graphics!&lt;br/&gt;\n\"\n"
"        \"&lt;br/&gt;\"\n"
"        \"&lt;img src='/computer.png' style='display:block;margin:auto'&gt;&lt;/img&gt;\"\n"
"        \"&lt;br/&gt;\"\n"
"        \"&lt;br/&gt;\"\n"
"    \"&lt;/div&gt;\"\n"
"\"&lt;div id='bottom'&gt;&lt;/div&gt;\"\n"
"\"&lt;/body&gt;\"\n"
"\"&lt;/html&gt;\";\n"
"</div>\n"
"\n"
"<p>The HTML has been updated to include a\n"
"<span class='coderef'>&lt;img&gt;</span> tag with a source\n"
"of \"/computer.png\".</p>\n"
"\n"
"<div class='code'>"
"unsigned char computer_png[] = {\n"
"  0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,\n"
"  0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x32, 0x00, 0x00, 0x00, 0x41,\n"
"  0x08, 0x06, 0x00, 0x00, 0x00, 0x93, 0x89, 0xf7, 0xde, 0x00, 0x00, 0x14,\n"
"  0x3c, 0x49, 0x44, 0x41, 0x54, 0x68, 0xde, 0xc5, 0x5a, 0x79, 0x7c, 0x54,\n"
"  0xe5, 0xb9, 0x7e, 0xce, 0x3a, 0x73, 0xce, 0x2c, 0x99, 0x99, 0x64, 0x26,\n"
"  0x93, 0x3d, 0x93, 0x05, 0x21, 0x0b, 0x61, 0x0b, 0x94, 0x45, 0xaa, 0x2d,\n"
"  0x46, 0x64, 0x2b, 0x54, 0x0d, 0x14, 0x6d, 0xa1, 0x57, 0xb1, 0x8b, 0xb7,\n"
"  0x45, 0x69, 0xed, 0x45, 0x5a, 0xad, 0x5a, 0xb8, 0x54, 0x05, 0xbd, 0xb6,\n"
"  0x4d, 0xbd, 0xde, 0xfe, 0x5a, 0x54, 0xe0, 0x16, 0x23, 0x22, 0xf6, 0x82,\n"
"  0x02, 0x8a, 0x6c, 0x12, 0x40, 0x40, 0x01, 0x21, 0x04, 0x08, 0x92, 0x6d,\n"
"  0x92, 0xcc, 0x90, 0x99, 0x4c, 0x66, 0xe6, 0xcc, 0x76, 0xe6, 0x9c, 0x73,\n"
"  0xff, 0x48, 0x66, 0x6e, 0xf6, 0x85, 0xa5, 0xf7, 0xfd, 0xfd, 0xf2, 0x47,\n"
"  0xe0, 0xe4, 0xfb, 0xde, 0xe7, 0x7b, 0x97, 0xef, 0x7d, 0x9f, 0xef, 0x25,\n"
"  0x70, 0x1b, 0xe4, 0xcc, 0x99, 0x33, 0xc4, 0xc2, 0x85, 0x0b, 0x27, 0x99,\n"
"  0xcd, 0xe6, 0x25, 0x73, 0xe7, 0xce, 0x2d, 0xe7, 0x38, 0xce, 0xe0, 0xf3,\n"
"  0xf9, 0xea, 0x9a, 0x9b, 0x9b, 0x6b, 0xf7, 0xee, 0xdd, 0x5b, 0x43, 0x10,\n"
"  0xc4, 0x05, 0x8d, 0x46, 0x53, 0x5d, 0x58, 0x58, 0x58, 0xfd, 0xce, 0x3b,\n"
"  0xef, 0x84, 0x18, 0x86, 0xb9, 0xe9, 0x3d, 0x89, 0x5b, 0xa5, 0xbc, 0x28,\n"
"  0x8a, 0x98, 0x30, 0x61, 0x42, 0xae, 0xcf, 0xe7, 0xfb, 0xfe, 0xd2, 0xa5,\n"
"  0x4b, 0x97, 0x8e, 0x1e, 0x3d, 0x3a, 0xdf, 0x66, 0xb3, 0x81, 0xa6, 0xe9,\n"
"  0x1e, 0xdf, 0xc9, 0xb2, 0x0c, 0xaf, 0xd7, 0x0b, 0xb7, 0xdb, 0x0d, 0xa7,\n"
"  0xd3, 0x19, 0x75, 0xb9, 0x5c, 0x97, 0xaa, 0xab, 0xab, 0xcf, 0x1e, 0x3b,\n"
"  0x76, 0xec, 0x4b, 0x8e, 0xe3, 0x4e, 0x17, 0x14, 0x14, 0x9c, 0x7a, 0xff,\n"
"  0xfd, 0xf7, 0x7d, 0x23, 0x05, 0x77, 0x53, 0x40, 0x64, 0x59, 0xc6, 0x84,\n"
"  0x09, 0x13, 0x92, 0x9c, 0x4e, 0xe7, 0xe2, 0x45, 0x8b, 0x16, 0x2d, 0x2d,\n"
"  0x29, 0x29, 0x99, 0x36, 0x6a, 0xd4, 0x28, 0xa8, 0x54, 0xaa, 0x91, 0x29,\n"
"  0x41, 0x10, 0x08, 0x04, 0x02, 0x68, 0x6b, 0x6b, 0x43, 0x6b, 0x6b, 0xab,\n"
"  0xe2, 0x70, 0x38, 0xce, 0x7f, 0xf2, 0xc9, 0x27, 0x47, 0x1a, 0x1b, 0x1b,\n"
"  0x0f, 0x66, 0x64, 0x64, 0xec, 0xff, 0xec, 0xb3, 0xcf, 0xdc, 0x43, 0x01,\n"
"  0xbb, 0x21, 0x20, 0x4b, 0x96, 0x2c, 0x61, 0x8f, 0x1c, 0x39, 0x32, 0x67,\n"
"  0xfa, 0xf4, 0xe9, 0xcb, 0xa7, 0x4f, 0x9f, 0x3e, 0x67, 0xf4, 0xe8, 0xd1,\n"
"  0x8c, 0x5e, 0xaf, 0xbf, 0xe5, 0x2e, 0xea, 0x70, 0x38, 0x50, 0x5f, 0x5f,\n"
"  0x2f, 0xee, 0xde, 0xbd, 0x7b, 0xc3, 0xae, 0x5d, 0xbb, 0xd6, 0xb0, 0x2c,\n"
"  0x3b, 0xe0, 0xb7, 0xf4, 0x70, 0x17, 0x8d, 0x46, 0xa3, 0xc8, 0xcf, 0xcf,\n"
"  0x9f, 0x9c, 0x99, 0x99, 0xb9, 0xac, 0xa8, 0xa8, 0x68, 0x71, 0x79, 0x79,\n"
"  0x79, 0x62, 0x6a, 0x6a, 0x2a, 0x14, 0x45, 0xc1, 0xed, 0x12, 0xab, 0xd5,\n"
"  0x8a, 0xdc, 0xdc, 0x5c, 0xa6, 0xb9, 0xb9, 0xf9, 0x3b, 0x24, 0x49, 0xae,\n"
"  0x19, 0xec, 0x5b, 0x7a, 0x28, 0xe5, 0x27, 0x4e, 0x9c, 0x98, 0xd2, 0xd8,\n"
"  0xd8, 0xf8, 0xf0, 0xd3, 0x4f, 0x3f, 0xbd, 0xfc, 0xf9, 0xe7, 0x9f, 0x2f,\n"
"  0xe8, 0xee, 0xf7, 0xb7, 0x0b, 0x04, 0x49, 0x92, 0x48, 0x48, 0x48, 0x80,\n"
"  0x4a, 0xa5, 0x82, 0x2c, 0xcb, 0x30, 0x9b, 0xcd, 0x7a, 0x59, 0x96, 0x09,\n"
"  0x00, 0xca, 0x88, 0x80, 0x2c, 0x59, 0xb2, 0x84, 0x39, 0x72, 0xe4, 0xc8,\n"
"  0xbc, 0xe5, 0xcb, 0x97, 0xff, 0xcb, 0x8a, 0x15, 0x2b, 0x66, 0x8f, 0x1e,\n"
"  0x3d, 0x9a, 0xd6, 0x68, 0x34, 0xb8, 0xdd, 0x42, 0x92, 0x24, 0x0c, 0x06,\n"
"  0x03, 0x78, 0x9e, 0x87, 0x28, 0x8a, 0x90, 0x65, 0xb9, 0x53, 0x49, 0x9a,\n"
"  0x36, 0x92, 0x24, 0xa9, 0x0c, 0xcb, 0x22, 0xa2, 0x28, 0xa2, 0xb4, 0xb4,\n"
"  0xd4, 0x26, 0xcb, 0xf2, 0x63, 0x05, 0x05, 0x05, 0xcb, 0xcb, 0xcb, 0xcb,\n"
"  0xad, 0x29, 0x29, 0x29, 0xf8, 0x67, 0x48, 0xcc, 0x02, 0x7a, 0xbd, 0x1e,\n"
"  0x91, 0x48, 0x04, 0x91, 0x48, 0xa4, 0xb7, 0x67, 0x70, 0x43, 0x59, 0x9f,\n"
"  0x6e, 0x68, 0x68, 0xc0, 0xa4, 0x49, 0x93, 0x66, 0x2e, 0x5b, 0xb6, 0xec,\n"
"  0x97, 0x3f, 0xfa, 0xd1, 0x8f, 0xe6, 0x15, 0x14, 0x14, 0x10, 0x83, 0x05,\n"
"  0xd5, 0xad, 0x14, 0x82, 0x20, 0xa0, 0xd7, 0xeb, 0x61, 0x30, 0x18, 0x20,\n"
"  0x49, 0x12, 0x82, 0xc1, 0x60, 0xbf, 0xdf, 0x29, 0x8a, 0x42, 0xee, 0xda,\n"
"  0xb5, 0x8b, 0x04, 0x20, 0x0f, 0x08, 0xe4, 0xce, 0x3b, 0xef, 0x5c, 0xbc,\n"
"  0x7e, 0xfd, 0xfa, 0x6d, 0x63, 0xc6, 0x8c, 0x01, 0x41, 0x10, 0xf8, 0x67,\n"
"  0x89, 0x56, 0xab, 0x85, 0xc9, 0x64, 0x82, 0xa2, 0x28, 0x03, 0x02, 0xe8,\n"
"  0x9e, 0xe6, 0x25, 0x49, 0x1a, 0x54, 0x39, 0xda, 0xed, 0x76, 0xdb, 0x72,\n"
"  0x72, 0x72, 0x40, 0xd3, 0x34, 0x68, 0x9a, 0x06, 0x49, 0x92, 0x20, 0x08,\n"
"  0x02, 0xe1, 0x70, 0x18, 0x92, 0x24, 0xdd, 0x72, 0x00, 0x1c, 0xc7, 0x21,\n"
"  0x31, 0x31, 0x11, 0x24, 0x49, 0x22, 0x1c, 0x0e, 0x0f, 0x3b, 0x61, 0x1c,\n"
"  0x3a, 0x74, 0x88, 0x04, 0x30, 0xa0, 0x42, 0x74, 0x52, 0x52, 0x92, 0x56,\n"
"  0xa5, 0x52, 0x41, 0x92, 0xa4, 0xb8, 0xe2, 0x14, 0x45, 0x41, 0xad, 0x56,\n"
"  0x83, 0x61, 0x18, 0x90, 0x24, 0x09, 0x49, 0x92, 0x10, 0x0e, 0x87, 0x47,\n"
"  0xb4, 0x71, 0x6f, 0x51, 0xa9, 0x54, 0x30, 0x99, 0x4c, 0x60, 0x18, 0x06,\n"
"  0x91, 0x48, 0x24, 0x1e, 0xc8, 0x43, 0x49, 0x6c, 0xbf, 0xfa, 0xfa, 0x7a,\n"
"  0x72, 0x50, 0x8b, 0xc8, 0xb2, 0xac, 0x63, 0x18, 0x06, 0xd1, 0x68, 0x34,\n"
"  0xfe, 0x8f, 0x92, 0x24, 0x41, 0x10, 0x84, 0xf8, 0xef, 0x0c, 0xc3, 0x40,\n"
"  0xad, 0x56, 0x43, 0xa7, 0xd3, 0x81, 0x24, 0x49, 0x44, 0xa3, 0xd1, 0x38,\n"
"  0x30, 0x51, 0x14, 0x07, 0x55, 0x84, 0x65, 0x59, 0x18, 0x8d, 0x46, 0xa8,\n"
"  0x54, 0x2a, 0x88, 0xa2, 0x88, 0x50, 0x28, 0x74, 0x43, 0xb1, 0x14, 0x0c,\n"
"  0x06, 0x07, 0x07, 0x92, 0x96, 0x96, 0xc6, 0x29, 0x8a, 0x02, 0xb5, 0x5a,\n"
"  0x8d, 0x48, 0x24, 0x02, 0x51, 0x14, 0x41, 0x51, 0x54, 0x9f, 0x3a, 0x4a,\n"
"  0x14, 0x45, 0xf8, 0x7c, 0xbe, 0xb8, 0x72, 0x6a, 0xb5, 0x1a, 0x46, 0xa3,\n"
"  0x11, 0x0c, 0xc3, 0x40, 0x14, 0xc5, 0x38, 0xb0, 0x98, 0xd5, 0x58, 0x96,\n"
"  0x45, 0x42, 0x42, 0x02, 0x38, 0x8e, 0xbb, 0x61, 0x00, 0xdd, 0xb3, 0xda,\n"
"  0xa9, 0x53, 0xa7, 0x06, 0x8f, 0x11, 0x8b, 0xc5, 0xc2, 0xca, 0xb2, 0x0c,\n"
"  0x96, 0x65, 0x41, 0x92, 0x24, 0x42, 0xa1, 0x50, 0x8f, 0xf4, 0xc7, 0xb2,\n"
"  0x6c, 0x1f, 0x60, 0xb1, 0x14, 0xe9, 0xf5, 0x7a, 0x41, 0x10, 0x04, 0x54,\n"
"  0x2a, 0x15, 0x38, 0x8e, 0xeb, 0x01, 0x8c, 0x65, 0xd9, 0x9b, 0x06, 0x10,\n"
"  0x73, 0xad, 0xae, 0x3d, 0x06, 0x07, 0xa2, 0x52, 0xa9, 0x54, 0xb1, 0x8f,\n"
"  0x63, 0x8a, 0xf7, 0xa7, 0xf4, 0x40, 0xc0, 0x14, 0x45, 0x41, 0x28, 0x14,\n"
"  0x8a, 0x2b, 0x4c, 0xd3, 0x34, 0xd2, 0xd2, 0xd2, 0x40, 0x10, 0x44, 0x0f,\n"
"  0x77, 0xbd, 0x59, 0x19, 0xea, 0x4a, 0xa0, 0x59, 0x96, 0x65, 0x07, 0x0b,\n"
"  0xe0, 0x91, 0x02, 0x8b, 0x46, 0xa3, 0xb7, 0xbc, 0x74, 0x21, 0x08, 0x02,\n"
"  0x8a, 0xa2, 0x0c, 0x6e, 0x11, 0x9d, 0x4e, 0xc7, 0xdc, 0xcc, 0xc9, 0x44,\n"
"  0x22, 0x11, 0x08, 0x82, 0x80, 0xee, 0xd5, 0x6f, 0x77, 0x0b, 0xdf, 0xac,\n"
"  0x0c, 0x77, 0x2d, 0x52, 0xa3, 0xd1, 0x30, 0xb1, 0x0f, 0x15, 0x45, 0x19,\n"
"  0x76, 0x5a, 0xec, 0x0e, 0xac, 0xbf, 0x5e, 0xe1, 0x56, 0x5a, 0xa5, 0xcb,\n"
"  0x22, 0x83, 0xbb, 0x16, 0x49, 0x92, 0x6c, 0xef, 0x0c, 0x21, 0x49, 0x12,\n"
"  0x64, 0x59, 0x86, 0x2c, 0xcb, 0x50, 0x14, 0x05, 0x2a, 0x95, 0x6a, 0xd0,\n"
"  0x53, 0xe9, 0xbd, 0x89, 0x2c, 0xcb, 0x7d, 0x12, 0xc4, 0xcd, 0x02, 0x19,\n"
"  0x4a, 0xfa, 0x00, 0x89, 0x5d, 0x88, 0x31, 0x45, 0x62, 0x25, 0x44, 0x0c,\n"
"  0x1c, 0x4d, 0xd3, 0xe0, 0x79, 0x7e, 0x44, 0xc0, 0x6e, 0xd6, 0xb5, 0x86,\n"
"  0xb3, 0x1e, 0xad, 0x28, 0x0a, 0x3b, 0x98, 0x02, 0x04, 0x41, 0x80, 0xe7,\n"
"  0xf9, 0x1e, 0x77, 0x4a, 0x7b, 0x7b, 0x3b, 0x24, 0x49, 0x82, 0xa2, 0x28,\n"
"  0x3d, 0xfe, 0xef, 0x76, 0x00, 0x19, 0x6e, 0x9c, 0xd0, 0x24, 0x49, 0x8e,\n"
"  0xc8, 0x07, 0x18, 0x86, 0x81, 0xc9, 0x64, 0x8a, 0x6f, 0x20, 0x08, 0x02,\n"
"  0x3a, 0x3a, 0x3a, 0xa0, 0xd5, 0x6a, 0xf1, 0xff, 0x29, 0x34, 0xd5, 0xe5,\n"
"  0x43, 0xb1, 0x80, 0x8a, 0x05, 0x3c, 0x41, 0x10, 0x20, 0x49, 0x72, 0x48,\n"
"  0xdf, 0xd5, 0x6a, 0xb5, 0x43, 0x7e, 0x77, 0x2b, 0x2c, 0x32, 0x24, 0x10,\n"
"  0x82, 0x20, 0xa8, 0xde, 0xca, 0x51, 0x14, 0x85, 0x68, 0x34, 0x1a, 0xef,\n"
"  0xd2, 0x62, 0x25, 0xcc, 0x70, 0x15, 0xbe, 0x4d, 0xae, 0xa5, 0x0c, 0x15,\n"
"  0x23, 0x74, 0x7f, 0x0a, 0xc4, 0xca, 0xfa, 0xee, 0x01, 0x1f, 0x03, 0x46,\n"
"  0x51, 0x14, 0x34, 0x1a, 0x4d, 0x3c, 0x21, 0xdc, 0xee, 0x3e, 0x46, 0x51,\n"
"  0x14, 0xf8, 0xfd, 0x7e, 0x65, 0x28, 0x8b, 0x30, 0x43, 0x29, 0xd3, 0x5f,\n"
"  0xc0, 0x7b, 0xbd, 0x5e, 0x44, 0x22, 0x11, 0x28, 0x8a, 0x02, 0x92, 0x24,\n"
"  0xc1, 0x71, 0x5c, 0x8f, 0x8d, 0x87, 0x2a, 0x4f, 0x64, 0x59, 0x86, 0xd3,\n"
"  0xe9, 0x44, 0x5b, 0x5b, 0x5b, 0xbc, 0xb1, 0xe2, 0x79, 0x1e, 0xa9, 0xa9,\n"
"  0xa9, 0x30, 0x1a, 0x8d, 0x7d, 0x80, 0x98, 0x4c, 0x26, 0xb8, 0xdd, 0xee,\n"
"  0x41, 0x7b, 0x76, 0x7a, 0xa4, 0x19, 0x82, 0x61, 0x98, 0xf8, 0x66, 0x8a,\n"
"  0xa2, 0xc0, 0xe3, 0xf1, 0xf4, 0x00, 0xb9, 0x76, 0xed, 0x5a, 0x04, 0x02,\n"
"  0x02, 0x96, 0x2f, 0xff, 0x21, 0xf2, 0xf3, 0xf3, 0xfb, 0x1c, 0xca, 0x7b,\n"
"  0xef, 0xbd, 0x87, 0xb7, 0xde, 0x7e, 0x1b, 0x8c, 0x5a, 0x0d, 0x8d, 0xa6,\n"
"  0x33, 0xc6, 0x34, 0x1a, 0x1e, 0x16, 0xb3, 0x05, 0xee, 0xb6, 0x36, 0x18,\n"
"  0x0d, 0x09, 0x78, 0xf0, 0xc1, 0x07, 0x51, 0x50, 0x50, 0x10, 0xdf, 0x23,\n"
"  0x3f, 0x3f, 0x5f, 0xa9, 0xad, 0xad, 0x1d, 0x5e, 0xd6, 0x8a, 0xb9, 0x56,\n"
"  0xac, 0x5e, 0x8a, 0xb9, 0x51, 0x6f, 0xda, 0xb3, 0xb7, 0x62, 0x6a, 0xb5,\n"
"  0x3a, 0xfe, 0x77, 0x9b, 0x37, 0x6f, 0xc6, 0xbc, 0x79, 0x73, 0x61, 0x4d,\n"
"  0xb1, 0xe2, 0x83, 0x0f, 0xfe, 0x81, 0x53, 0xa7, 0x4e, 0x61, 0xe1, 0xc2,\n"
"  0x85, 0x71, 0x8b, 0x29, 0x8a, 0x82, 0xaa, 0xaa, 0x2a, 0xb8, 0xdd, 0x6e,\n"
"  0xc8, 0xb2, 0x8c, 0x94, 0xb4, 0x34, 0x18, 0x4c, 0x89, 0x08, 0x86, 0xc2,\n"
"  0xf0, 0x78, 0xbd, 0x28, 0x2a, 0x29, 0x81, 0xc9, 0x68, 0xc4, 0x3f, 0x76,\n"
"  0xed, 0xc6, 0x89, 0x13, 0x27, 0x50, 0x5e, 0x5e, 0x3e, 0xbc, 0x18, 0xa1,\n"
"  0x28, 0x8a, 0xee, 0xee, 0x5a, 0x04, 0x41, 0xf4, 0x50, 0x5c, 0x14, 0x45,\n"
"  0xf8, 0xfd, 0xfe, 0x78, 0x46, 0xe3, 0x38, 0x0e, 0x03, 0xd1, 0x97, 0xc7,\n"
"  0x8f, 0x1f, 0x87, 0xc1, 0xa8, 0x47, 0xb2, 0x35, 0x19, 0x2a, 0x96, 0xc5,\n"
"  0xe2, 0xc5, 0x0f, 0xe2, 0xd2, 0xa5, 0xcb, 0x78, 0xf6, 0xd9, 0x67, 0xb1,\n"
"  0x62, 0xc5, 0x0a, 0xdc, 0x71, 0xc7, 0x1d, 0x50, 0x14, 0x05, 0x1b, 0x36,\n"
"  0x6c, 0x88, 0x57, 0x11, 0x4d, 0x4d, 0x4d, 0x38, 0x78, 0xf0, 0x20, 0xb6,\n"
"  0xfc, 0x7d, 0x1b, 0x58, 0x96, 0x45, 0xcd, 0xa5, 0x4b, 0xc8, 0xce, 0xca,\n"
"  0xc6, 0x98, 0x82, 0x02, 0x04, 0x04, 0x01, 0x2f, 0xbd, 0xf4, 0x12, 0x72,\n"
"  0x73, 0x73, 0xc1, 0xb2, 0xec, 0xa0, 0x40, 0xa8, 0x59, 0xb3, 0x66, 0x3d,\n"
"  0x65, 0xb3, 0xd9, 0xb4, 0x1c, 0xc7, 0xf5, 0xdb, 0x82, 0x52, 0x14, 0x05,\n"
"  0x96, 0x65, 0xa1, 0x52, 0xa9, 0xc0, 0xb2, 0x2c, 0x82, 0xc1, 0x20, 0x7c,\n"
"  0x3e, 0x1f, 0xfc, 0x7e, 0x3f, 0x22, 0x91, 0x08, 0x28, 0x8a, 0x82, 0xa2,\n"
"  0x28, 0x60, 0x18, 0x06, 0x1a, 0x8d, 0x06, 0xdb, 0xdf, 0xdd, 0x8e, 0x84,\n"
"  0x04, 0x1d, 0x2c, 0xc9, 0xc9, 0xa0, 0x29, 0x1a, 0x06, 0xa3, 0x11, 0xa5,\n"
"  0x93, 0x4b, 0xb1, 0x67, 0xef, 0x1e, 0x5c, 0xb9, 0x7c, 0x05, 0x79, 0x79,\n"
"  0x79, 0xf1, 0x83, 0x50, 0x14, 0x05, 0x3a, 0x9d, 0x0e, 0xc5, 0xc5, 0xc5,\n"
"  0x98, 0x31, 0x7d, 0x1a, 0xf6, 0xee, 0xf9, 0x08, 0x20, 0x29, 0x04, 0x02,\n"
"  0x01, 0x90, 0x24, 0x05, 0xa3, 0xc9, 0x88, 0xa4, 0xa4, 0x44, 0x3c, 0xf7,\n"
"  0xdb, 0xdf, 0x82, 0x61, 0x98, 0x0d, 0x0e, 0x87, 0x23, 0x3c, 0x20, 0x90,\n"
"  0xb2, 0xb2, 0xb2, 0x7f, 0xcb, 0xce, 0xce, 0xe6, 0x07, 0x02, 0xd2, 0xdb,\n"
"  0x8d, 0x58, 0x96, 0x05, 0xcf, 0xf3, 0xf1, 0xac, 0xe5, 0xf7, 0xfb, 0xe1,\n"
"  0xf5, 0x7a, 0xa1, 0xd7, 0xeb, 0xc1, 0xf3, 0x3c, 0xc6, 0x8e, 0x1d, 0x8b,\n"
"  0x37, 0xdf, 0x7c, 0x0b, 0x46, 0x93, 0x11, 0x16, 0x4b, 0x32, 0x98, 0x2e,\n"
"  0x42, 0xa3, 0xb0, 0xb0, 0x10, 0xb2, 0x22, 0xa3, 0xe2, 0x4f, 0x15, 0x98,\n"
"  0x3c, 0x79, 0x72, 0xdc, 0x1d, 0x63, 0x62, 0x30, 0x18, 0x30, 0x79, 0xf2,\n"
"  0x64, 0x6c, 0xde, 0xb2, 0x19, 0x14, 0xc3, 0x76, 0x1e, 0x12, 0x49, 0xc1,\n"
"  0x60, 0x30, 0x62, 0xca, 0x94, 0x29, 0xd8, 0xbd, 0x6b, 0xd7, 0x94, 0x69,\n"
"  0xd3, 0xa6, 0x55, 0xd6, 0xd7, 0xd7, 0xf7, 0x9b, 0x45, 0xa8, 0x7b, 0xef,\n"
"  0xbd, 0x77, 0x75, 0x66, 0x66, 0x26, 0xc7, 0xf3, 0x3c, 0xc2, 0xe1, 0x30,\n"
"  0xa2, 0xd1, 0x68, 0x9c, 0x88, 0x20, 0x08, 0x62, 0xd0, 0xc0, 0x27, 0x49,\n"
"  0x12, 0x07, 0x0e, 0x1c, 0xc0, 0xf9, 0xf3, 0xe7, 0x51, 0x54, 0x54, 0xd4,\n"
"  0x15, 0xb4, 0x1a, 0x4c, 0x9d, 0x3a, 0x0d, 0x9b, 0xfe, 0xb6, 0x09, 0x46,\n"
"  0x63, 0x02, 0xcc, 0x96, 0x64, 0xd0, 0x34, 0x0d, 0x45, 0x96, 0x61, 0x34,\n"
"  0x1a, 0xe1, 0xf7, 0xf9, 0x90, 0x9e, 0x9e, 0x8e, 0xfe, 0x48, 0x6f, 0xbd,\n"
"  0x5e, 0x0f, 0xb7, 0xcb, 0x85, 0x36, 0xb7, 0x1b, 0xf6, 0xe6, 0x16, 0x50,\n"
"  0x14, 0x09, 0x92, 0x24, 0x91, 0x9c, 0x6c, 0x41, 0x51, 0x51, 0x91, 0xed,\n"
"  0x9d, 0x6d, 0xdb, 0x4a, 0x4a, 0x4b, 0x4b, 0xb7, 0xdb, 0xed, 0xf6, 0x3e,\n"
"  0xa7, 0x4d, 0x76, 0xfd, 0xf4, 0x50, 0x8e, 0xa6, 0x69, 0xc4, 0x08, 0x89,\n"
"  0x60, 0x30, 0x08, 0x41, 0x10, 0x20, 0x08, 0x42, 0x0f, 0x6b, 0x29, 0x8a,\n"
"  0x82, 0x0f, 0x3e, 0xf8, 0x00, 0x09, 0x06, 0x3d, 0x4c, 0x89, 0x06, 0x6c,\n"
"  0xdd, 0xba, 0x35, 0xce, 0xc2, 0xe4, 0xe4, 0xe4, 0x60, 0xcd, 0x9a, 0x5f,\n"
"  0xa3, 0xb2, 0x72, 0x3b, 0xae, 0x5d, 0xbb, 0xda, 0x99, 0xa2, 0x29, 0x0a,\n"
"  0x34, 0x4d, 0xe1, 0xf4, 0xe9, 0xd3, 0x48, 0x4e, 0x4e, 0x1e, 0xd0, 0xe2,\n"
"  0xd7, 0xaf, 0x5f, 0x87, 0xd1, 0x60, 0x04, 0x41, 0x10, 0xa8, 0xbd, 0xfa,\n"
"  0x35, 0x1a, 0x9b, 0x1a, 0xd1, 0xd8, 0x64, 0x87, 0xc5, 0x9a, 0x82, 0x9f,\n"
"  0x3f, 0xf1, 0xc4, 0xbc, 0x9a, 0x9a, 0x9a, 0x37, 0x57, 0xae, 0x5c, 0xd9,\n"
"  0xe7, 0x74, 0xc9, 0xde, 0x37, 0x7b, 0xef, 0x5e, 0x83, 0xe3, 0x38, 0x68,\n"
"  0x34, 0x1a, 0x70, 0x1c, 0x87, 0x40, 0x20, 0x80, 0xf6, 0xf6, 0x76, 0xb8,\n"
"  0x5c, 0x2e, 0x1c, 0x3f, 0x7e, 0x1c, 0xe9, 0xe9, 0x69, 0x58, 0xf8, 0x9d,\n"
"  0x85, 0x98, 0x3b, 0x77, 0x1e, 0xf4, 0x09, 0x5a, 0x54, 0x56, 0x56, 0xc6,\n"
"  0xc1, 0x72, 0x1c, 0x87, 0x94, 0x14, 0x2b, 0x14, 0x00, 0x0d, 0x8d, 0xf5,\n"
"  0x80, 0xa2, 0x20, 0x14, 0x0a, 0xc3, 0x6a, 0x4d, 0x19, 0x30, 0x0b, 0xfa,\n"
"  0xfd, 0x7e, 0x5c, 0xae, 0xbd, 0x0a, 0x9e, 0xe7, 0x61, 0x32, 0x1a, 0x41,\n"
"  0x00, 0xa8, 0xbd, 0xfa, 0x35, 0x9a, 0xec, 0x4d, 0x68, 0x6c, 0x6c, 0x42,\n"
"  0x46, 0x66, 0x16, 0x1e, 0x5c, 0xbc, 0x78, 0xe9, 0x96, 0x2d, 0x5b, 0x7e,\n"
"  0x31, 0xa4, 0x45, 0x06, 0x73, 0x23, 0xad, 0x56, 0x0b, 0xa3, 0xd1, 0x88,\n"
"  0xc4, 0xc4, 0x44, 0xe4, 0xe6, 0xe6, 0xa2, 0xba, 0xfa, 0x22, 0x28, 0x8a,\n"
"  0x82, 0x39, 0xc9, 0x8c, 0xf9, 0xf3, 0xe7, 0x83, 0xa4, 0x80, 0xed, 0xdb,\n"
"  0xb7, 0xa3, 0xb6, 0xb6, 0x16, 0xbb, 0x76, 0xed, 0x42, 0x66, 0x66, 0x26,\n"
"  0x34, 0xbc, 0x06, 0xb2, 0x2c, 0xa3, 0xa1, 0xa9, 0x01, 0x4d, 0x4d, 0x4d,\n"
"  0x28, 0x2e, 0x2e, 0x1e, 0x38, 0xf3, 0x50, 0x14, 0x04, 0xbf, 0x17, 0x59,\n"
"  0x59, 0x19, 0x30, 0x18, 0x12, 0x60, 0xec, 0x62, 0x22, 0xaf, 0xd4, 0x5e,\n"
"  0x45, 0x93, 0xdd, 0x8e, 0x86, 0xc6, 0x26, 0x14, 0x15, 0x8f, 0x45, 0x4e,\n"
"  0x6e, 0xee, 0xf3, 0x77, 0xdf, 0x7d, 0x77, 0x4a, 0xef, 0x18, 0xf9, 0x4d,\n"
"  0x46, 0x46, 0x06, 0x13, 0x3b, 0x79, 0x86, 0x61, 0xe2, 0x99, 0x68, 0xb0,\n"
"  0xc0, 0xd7, 0x68, 0x34, 0x08, 0x85, 0x42, 0x68, 0x6f, 0x6f, 0x47, 0xb6,\n"
"  0x2d, 0x1b, 0x6a, 0x15, 0x87, 0x8c, 0xf4, 0x74, 0x5c, 0xac, 0xa9, 0xc6,\n"
"  0xd9, 0xb3, 0x67, 0x60, 0x49, 0x4e, 0xc2, 0xe8, 0xd1, 0x63, 0x10, 0x63,\n"
"  0xf1, 0xc3, 0xa1, 0x30, 0x4e, 0x9c, 0x38, 0x81, 0x09, 0xe3, 0x27, 0xc2,\n"
"  0x6c, 0x36, 0xf7, 0x59, 0x2f, 0x14, 0x0a, 0x61, 0xe3, 0xc6, 0x8d, 0x78,\n"
"  0xf2, 0x97, 0x2b, 0x31, 0x63, 0xfa, 0x54, 0xd8, 0xed, 0x2d, 0x10, 0x02,\n"
"  0x02, 0x08, 0x10, 0x08, 0x06, 0x83, 0x68, 0xf7, 0x78, 0xc0, 0x30, 0x0c,\n"
"  0x14, 0x05, 0xb0, 0x65, 0x67, 0x31, 0x3b, 0xdf, 0x7f, 0x5f, 0x16, 0x45,\n"
"  0xf1, 0xe3, 0xee, 0x40, 0x9e, 0xc9, 0xc8, 0xc8, 0xa0, 0x83, 0xc1, 0x20,\n"
"  0x22, 0x91, 0x08, 0x48, 0x92, 0x84, 0x4a, 0xa5, 0x82, 0x56, 0xab, 0x05,\n"
"  0xcf, 0xf3, 0x71, 0xb6, 0x31, 0x56, 0x3c, 0x76, 0x97, 0xd4, 0xd4, 0x54,\n"
"  0x6c, 0xdd, 0xba, 0x15, 0xe3, 0xc7, 0x8d, 0x83, 0x46, 0xab, 0x05, 0xcf,\n"
"  0xf1, 0xc8, 0xce, 0xce, 0x42, 0x71, 0x51, 0x31, 0x72, 0xf3, 0xf2, 0xba,\n"
"  0xca, 0x1a, 0x02, 0x04, 0xd1, 0x79, 0xda, 0xc1, 0x60, 0x10, 0x97, 0x2f,\n"
"  0x5d, 0x41, 0x49, 0x49, 0x49, 0x8f, 0x02, 0x34, 0x14, 0x0a, 0xe1, 0xe5,\n"
"  0x97, 0x5f, 0xc6, 0x77, 0x1f, 0xf8, 0x0e, 0x0a, 0x0b, 0x0b, 0x91, 0x94,\n"
"  0x64, 0x41, 0x46, 0x66, 0x0a, 0x9a, 0x9a, 0xec, 0x08, 0x86, 0x42, 0x00,\n"
"  0x3a, 0x9f, 0xe6, 0x3c, 0x1d, 0x1d, 0x60, 0x18, 0x1a, 0xc9, 0x96, 0x64,\n"
"  0x38, 0x1c, 0xad, 0xe3, 0xa2, 0xd1, 0xa8, 0xc5, 0x64, 0x32, 0x99, 0x9e,\n"
"  0x7c, 0xf2, 0xc9, 0xf3, 0x54, 0x59, 0x59, 0xd9, 0xb3, 0x99, 0x99, 0x99,\n"
"  0x54, 0xac, 0xfe, 0x89, 0x44, 0x22, 0x08, 0x06, 0x83, 0x08, 0x04, 0x02,\n"
"  0x90, 0x24, 0x09, 0x14, 0x45, 0x81, 0xe7, 0x79, 0x68, 0xb5, 0x5a, 0x70,\n"
"  0x1c, 0x17, 0xf7, 0xef, 0x58, 0xa9, 0x9f, 0x9f, 0x9f, 0x8f, 0x37, 0xdf,\n"
"  0x7c, 0x0b, 0x77, 0xdf, 0x75, 0x17, 0x48, 0x8a, 0x84, 0x5a, 0xc5, 0x81,\n"
"  0x55, 0xb1, 0x5d, 0xc1, 0xdb, 0xf3, 0x85, 0xcf, 0x6c, 0x36, 0xc3, 0xeb,\n"
"  0xed, 0xc0, 0xa1, 0x43, 0x87, 0x31, 0x7e, 0xfc, 0x78, 0x50, 0x14, 0x85,\n"
"  0x48, 0x24, 0x82, 0xd7, 0x5e, 0x7b, 0x0d, 0x0b, 0x16, 0xcd, 0x43, 0xf1,\n"
"  0xd8, 0x62, 0x18, 0xf4, 0x26, 0xb8, 0x3d, 0x6d, 0x90, 0x15, 0x19, 0xde,\n"
"  0x8e, 0x0e, 0x78, 0xbd, 0x7e, 0xe8, 0xb4, 0x5a, 0x30, 0x34, 0x03, 0x49,\n"
"  0x92, 0xe0, 0x74, 0x3a, 0x41, 0x92, 0x24, 0xc6, 0x8f, 0x1f, 0xcf, 0x9a,\n"
"  0x92, 0x92, 0xbe, 0x11, 0x89, 0x88, 0xf7, 0xef, 0xdb, 0xbb, 0x87, 0x8c,\n"
"  0x01, 0x21, 0xfb, 0x2b, 0xc3, 0x63, 0xd4, 0x68, 0x20, 0x10, 0x88, 0x33,\n"
"  0x88, 0xb1, 0x8b, 0x4f, 0xa3, 0xd1, 0xc4, 0x2d, 0x17, 0x8d, 0x46, 0xd1,\n"
"  0xd0, 0xd0, 0x80, 0xfc, 0xfc, 0xfc, 0xae, 0x74, 0xdd, 0xf9, 0xb8, 0x24,\n"
"  0x08, 0x01, 0xf8, 0x7c, 0x3e, 0xa8, 0xd5, 0xaa, 0x78, 0xbf, 0x93, 0x64,\n"
"  0x4e, 0x42, 0x20, 0x20, 0x60, 0xff, 0xfe, 0x4f, 0x51, 0x5c, 0x5c, 0x8c,\n"
"  0x37, 0xde, 0x78, 0x03, 0xb3, 0xca, 0xee, 0x46, 0x49, 0xc9, 0x58, 0x18,\n"
"  0x13, 0x4c, 0x68, 0xef, 0x70, 0x23, 0x14, 0x0e, 0xe2, 0xc4, 0xf1, 0x93,\n"
"  0xf8, 0xfa, 0xca, 0x35, 0x24, 0xe8, 0x74, 0xa8, 0xfa, 0xec, 0x33, 0xe1,\n"
"  0xe4, 0x89, 0xe3, 0x5f, 0x9a, 0x12, 0x4d, 0xe9, 0x1c, 0xaf, 0x41, 0xab,\n"
"  0xd3, 0x09, 0x95, 0x4a, 0x85, 0x51, 0xf9, 0xf9, 0x18, 0x53, 0x50, 0x80,\n"
"  0x13, 0xc7, 0x8f, 0x8f, 0xa3, 0x7b, 0x3f, 0x88, 0x6a, 0xb5, 0x5a, 0xfc,\n"
"  0xe1, 0x0f, 0x7f, 0x80, 0xcd, 0x66, 0x43, 0x6a, 0x6a, 0x2a, 0x2c, 0x16,\n"
"  0x0b, 0x8c, 0x46, 0x23, 0xa2, 0xd1, 0x28, 0xa2, 0xd1, 0x28, 0x04, 0x41,\n"
"  0x88, 0x5f, 0x8c, 0x31, 0xea, 0x74, 0xca, 0x94, 0x29, 0x78, 0xe5, 0x95,\n"
"  0x57, 0x90, 0x99, 0x95, 0x09, 0x82, 0x20, 0x50, 0x5f, 0x57, 0x87, 0x2b,\n"
"  0xb5, 0x57, 0xd0, 0xda, 0xda, 0x0a, 0x97, 0xcb, 0x8d, 0xfb, 0xef, 0x5f,\n"
"  0x04, 0x9b, 0x2d, 0xa7, 0xf3, 0x90, 0x00, 0x14, 0x16, 0x16, 0x02, 0x0a,\n"
"  0x30, 0x7f, 0xfe, 0x7c, 0xbc, 0xf8, 0xf2, 0x7a, 0x94, 0x8c, 0x2b, 0x89,\n"
"  0x83, 0x08, 0x86, 0x02, 0xf8, 0xe2, 0xd4, 0x97, 0xb8, 0x7a, 0xf9, 0x1a,\n"
"  0x1e, 0x79, 0xe4, 0x91, 0xd8, 0x9e, 0xf5, 0x69, 0x69, 0x69, 0xd3, 0x3e,\n"
"  0xfa, 0xe8, 0xa3, 0x03, 0xd3, 0xbf, 0x79, 0xd7, 0x4c, 0x49, 0x92, 0x70,\n"
"  0xad, 0xbe, 0x0e, 0xb2, 0x2c, 0x43, 0xaf, 0xd7, 0x41, 0x14, 0xc5, 0x60,\n"
"  0x1f, 0x20, 0x34, 0x4d, 0x63, 0xf6, 0xec, 0xd9, 0x38, 0x7b, 0xf6, 0x2c,\n"
"  0x0e, 0x1e, 0x3c, 0x08, 0x00, 0x50, 0xab, 0xd5, 0xc8, 0xc9, 0xc9, 0x41,\n"
"  0x4a, 0x4a, 0x0a, 0x92, 0x93, 0x93, 0xa1, 0xd7, 0xeb, 0xe3, 0x3c, 0x6f,\n"
"  0x8c, 0x0f, 0x7e, 0xe8, 0xa1, 0x87, 0xf0, 0xf4, 0xea, 0x35, 0xc8, 0xcb,\n"
"  0xcb, 0x43, 0x69, 0x69, 0x29, 0x26, 0x4e, 0x28, 0x85, 0xd5, 0x6a, 0x85,\n"
"  0x20, 0x08, 0x78, 0xe5, 0xd5, 0x8d, 0x58, 0xb6, 0xec, 0x07, 0x48, 0x4f,\n"
"  0xcf, 0x40, 0x28, 0x14, 0x82, 0x20, 0x08, 0xa8, 0xa9, 0xa9, 0xc1, 0xbf,\n"
"  0xbf, 0xb8, 0x16, 0xa5, 0x93, 0x27, 0x75, 0x81, 0x68, 0x47, 0x30, 0x14,\n"
"  0xc0, 0x99, 0x2f, 0xcf, 0xe1, 0xec, 0x97, 0xe7, 0xb1, 0x62, 0xc5, 0x8a,\n"
"  0x78, 0x1c, 0x49, 0x92, 0x24, 0xbd, 0xfb, 0xee, 0xbb, 0xb2, 0xc9, 0x64,\n"
"  0xca, 0x65, 0x58, 0x16, 0xb2, 0x2c, 0x43, 0x10, 0x02, 0x70, 0xb7, 0xb7,\n"
"  0xe3, 0xd4, 0xe7, 0xc7, 0xa1, 0x62, 0xd9, 0xa7, 0xfa, 0x24, 0x74, 0x8f,\n"
"  0xc7, 0x83, 0xec, 0xec, 0x6c, 0x94, 0x94, 0x94, 0xa0, 0xae, 0xae, 0x0e,\n"
"  0x3b, 0x76, 0xec, 0x40, 0x20, 0x10, 0x40, 0x75, 0x75, 0x35, 0xaa, 0xab,\n"
"  0xab, 0x01, 0x00, 0x3a, 0x9d, 0x0e, 0xd9, 0xd9, 0xd9, 0x98, 0x34, 0x69,\n"
"  0x52, 0x9c, 0xb0, 0x33, 0x1a, 0x8d, 0xa8, 0xa8, 0xa8, 0x80, 0x2c, 0xcb,\n"
"  0xb0, 0x58, 0x2c, 0x3d, 0xd6, 0x5c, 0xf9, 0xf3, 0x27, 0xf0, 0xc7, 0x3f,\n"
"  0xbe, 0x86, 0x99, 0xdf, 0x9c, 0x89, 0x37, 0xb6, 0x1d, 0x80, 0xc6, 0x60,\n"
"  0xc1, 0xbf, 0x3d, 0x7a, 0x0f, 0xa6, 0x4c, 0x99, 0x0c, 0x43, 0x82, 0x09,\n"
"  0x1d, 0x3e, 0x0f, 0x82, 0x41, 0x01, 0x17, 0xab, 0x6b, 0x70, 0xea, 0xc4,\n"
"  0x17, 0xf8, 0xf1, 0x8f, 0x7f, 0xdc, 0xa3, 0xa9, 0xa3, 0x69, 0xba, 0xab,\n"
"  0x2c, 0x21, 0xa8, 0x98, 0xdb, 0x27, 0x25, 0x25, 0xa2, 0xee, 0xeb, 0x5a,\n"
"  0xb8, 0xdb, 0xda, 0x1e, 0x77, 0x3a, 0x9d, 0x5b, 0xe8, 0xfe, 0xde, 0xda,\n"
"  0x23, 0x91, 0x08, 0x3c, 0x1e, 0x0f, 0xb2, 0xb2, 0xb2, 0xf0, 0xb3, 0x9f,\n"
"  0xfd, 0x0c, 0x76, 0xbb, 0x1d, 0xa1, 0x50, 0x28, 0xfe, 0xa4, 0xe0, 0x70,\n"
"  0x38, 0xd0, 0xd4, 0xd4, 0xd4, 0x6f, 0xb3, 0xd4, 0x9f, 0x8c, 0x1e, 0x3d,\n"
"  0x1a, 0x33, 0x66, 0xcc, 0xc4, 0xb6, 0xfd, 0xb5, 0x98, 0x70, 0xdf, 0x4f,\n"
"  0x21, 0xcb, 0x0a, 0x08, 0x8d, 0x09, 0x46, 0x43, 0x22, 0xbc, 0x3e, 0x0f,\n"
"  0x02, 0x41, 0x01, 0x5f, 0x7f, 0x5d, 0x87, 0x23, 0x87, 0xaa, 0xf0, 0x93,\n"
"  0x9f, 0xfc, 0xa4, 0xcf, 0x85, 0xc9, 0x30, 0x8c, 0x48, 0x92, 0x24, 0x48,\n"
"  0x92, 0xd8, 0x60, 0x6f, 0x68, 0xd8, 0x60, 0xb1, 0x5a, 0x61, 0xaf, 0xaf,\n"
"  0x47, 0x53, 0x7d, 0xfd, 0x4a, 0x41, 0x10, 0xfe, 0x4c, 0x10, 0x04, 0x68,\n"
"  0x62, 0x80, 0x62, 0x4a, 0x14, 0x45, 0xb8, 0x5c, 0x2e, 0xf0, 0x3c, 0xdf,\n"
"  0x83, 0x94, 0x56, 0x14, 0x05, 0x39, 0x39, 0x39, 0xf1, 0xf2, 0x65, 0x38,\n"
"  0x72, 0xf2, 0xe4, 0x49, 0x54, 0x1e, 0xb8, 0x82, 0x51, 0x53, 0x16, 0xa0,\n"
"  0xc0, 0x66, 0x81, 0x57, 0x08, 0xe2, 0xaf, 0xfb, 0xea, 0xa0, 0xa2, 0x15,\n"
"  0x14, 0xdd, 0x91, 0x84, 0xba, 0xab, 0xf5, 0x58, 0xfb, 0xfc, 0x3a, 0xe4,\n"
"  0xe7, 0x8f, 0x42, 0x24, 0x12, 0xe9, 0xd3, 0x26, 0x30, 0x0c, 0xe3, 0xe9,\n"
"  0xe2, 0x11, 0x36, 0xa6, 0xa7, 0xa7, 0xd7, 0x84, 0x02, 0xc2, 0xd4, 0x70,\n"
"  0x38, 0x7c, 0xd8, 0xef, 0xf7, 0xef, 0x8b, 0xa9, 0x4f, 0x0f, 0xd5, 0x2b,\n"
"  0x77, 0x7f, 0xf0, 0xb9, 0x11, 0x1e, 0xea, 0xc4, 0x89, 0x13, 0x58, 0xff,\n"
"  0xd7, 0xbd, 0x18, 0x35, 0x79, 0x01, 0xc6, 0xd8, 0x2c, 0xf0, 0x07, 0xc3,\n"
"  0x70, 0xba, 0x7d, 0x88, 0x44, 0xc2, 0x58, 0xbb, 0xf5, 0x0c, 0x1e, 0xfd,\n"
"  0xb6, 0x15, 0xef, 0xbc, 0xf5, 0x27, 0x94, 0x2f, 0x2e, 0x87, 0x28, 0x46,\n"
"  0xb0, 0x7e, 0xfd, 0x7a, 0xac, 0x5e, 0xbd, 0x3a, 0x4e, 0x2f, 0x29, 0x8a,\n"
"  0x02, 0x97, 0xcb, 0xd5, 0x1e, 0x8b, 0x5f, 0x00, 0xbb, 0xbb, 0x7e, 0x7a,\n"
"  0xdc, 0x45, 0xa4, 0x72, 0x1b, 0x47, 0x17, 0x8e, 0x1d, 0x3b, 0x86, 0xdf,\n"
"  0xff, 0x6d, 0x1f, 0xf2, 0x4b, 0x17, 0xa0, 0x30, 0xc7, 0x02, 0x21, 0x18,\n"
"  0x86, 0xc3, 0xd5, 0x81, 0x7a, 0xfb, 0x75, 0xf8, 0x85, 0x00, 0x64, 0x49,\n"
"  0xc4, 0x8e, 0x23, 0x75, 0x30, 0x27, 0x99, 0xa1, 0xd7, 0xeb, 0x90, 0x97,\n"
"  0x97, 0x87, 0xbb, 0xee, 0x9a, 0x89, 0x75, 0xeb, 0xd6, 0xc5, 0x93, 0x48,\n"
"  0x57, 0xc3, 0x36, 0xa4, 0xe9, 0xc9, 0xc1, 0xa6, 0x09, 0x6e, 0x46, 0x0e,\n"
"  0x1f, 0x3e, 0x8c, 0x0d, 0x6f, 0x7f, 0x8a, 0xbc, 0xd2, 0xf9, 0x28, 0xca,\n"
"  0xb5, 0x40, 0x08, 0x85, 0xe1, 0x74, 0x7b, 0x51, 0x6f, 0x6f, 0x83, 0xd7,\n"
"  0x2f, 0x40, 0x96, 0x44, 0x68, 0x59, 0x02, 0xfe, 0xeb, 0xd7, 0x50, 0x54,\n"
"  0x5c, 0x04, 0x8b, 0xc5, 0x02, 0x9e, 0xe7, 0x91, 0x92, 0x9a, 0x82, 0x7b,\n"
"  0xee, 0xf9, 0x36, 0xd6, 0xae, 0x5b, 0x0b, 0x8f, 0xc7, 0x03, 0x8a, 0xa2,\n"
"  0xd0, 0xd2, 0xd2, 0xe2, 0x1d, 0x92, 0xd7, 0xba, 0x1d, 0x20, 0x76, 0xef,\n"
"  0xde, 0x8d, 0x4d, 0x1f, 0x7e, 0x85, 0x9c, 0x89, 0x73, 0x51, 0x94, 0xd3,\n"
"  0x09, 0xc2, 0xe1, 0xf2, 0xa2, 0xc1, 0xde, 0x86, 0x0e, 0x9f, 0x1f, 0xb2,\n"
"  0x24, 0x82, 0xa3, 0x15, 0x90, 0x81, 0x16, 0x64, 0xa8, 0x9d, 0x98, 0x31,\n"
"  0xe3, 0xbb, 0x5d, 0xd3, 0x0e, 0x9d, 0xef, 0x2e, 0x16, 0xab, 0x05, 0xf7,\n"
"  0xdd, 0x77, 0x2f, 0x5e, 0x78, 0xe1, 0x05, 0x94, 0x95, 0x95, 0x21, 0x12,\n"
"  0x89, 0xec, 0x1b, 0xb1, 0x45, 0x46, 0xf2, 0xe2, 0xda, 0x9f, 0x54, 0x55,\n"
"  0x55, 0x61, 0xd3, 0x87, 0x5f, 0xc1, 0x36, 0x61, 0x0e, 0x8a, 0x72, 0x2d,\n"
"  0x08, 0x84, 0x23, 0x70, 0xba, 0xbc, 0x68, 0x6c, 0x71, 0xa1, 0xdd, 0xeb,\n"
"  0x83, 0x2c, 0x89, 0x60, 0x09, 0x19, 0x6a, 0xc9, 0x8d, 0x6f, 0xd8, 0x48,\n"
"  0xb0, 0xac, 0x1a, 0xb5, 0x57, 0x2e, 0x83, 0x20, 0x08, 0x30, 0x4c, 0xe7,\n"
"  0x25, 0xcb, 0xd0, 0x0c, 0x92, 0xcc, 0x49, 0x58, 0xb8, 0x68, 0x01, 0x5e,\n"
"  0xfd, 0x8f, 0x57, 0x3b, 0x48, 0x92, 0x6c, 0x1a, 0x0e, 0x10, 0xb9, 0x77,\n"
"  0x73, 0xd3, 0xdc, 0xdc, 0x0c, 0x87, 0xc3, 0x11, 0xe7, 0xae, 0x46, 0x12,\n"
"  0x13, 0x5b, 0xf6, 0x5d, 0x44, 0xf6, 0xb8, 0xfb, 0x50, 0x9c, 0x63, 0x46,\n"
"  0x20, 0x14, 0x81, 0xc3, 0xd5, 0x81, 0xa6, 0x56, 0x17, 0xdc, 0x1e, 0x2f,\n"
"  0x64, 0x49, 0x04, 0x0d, 0x09, 0x09, 0x74, 0x00, 0x63, 0x0c, 0x1e, 0x3c,\n"
"  0xf6, 0xd8, 0x63, 0x58, 0xbd, 0x7a, 0x35, 0xf6, 0xee, 0xfd, 0x04, 0x17,\n"
"  0x2f, 0x5e, 0x00, 0x45, 0x91, 0x3d, 0xc0, 0x98, 0x4c, 0x26, 0xfc, 0xe6,\n"
"  0x37, 0x6b, 0x12, 0x8c, 0x46, 0xc3, 0xa7, 0x3a, 0x9d, 0x6e, 0xe2, 0xa0,\n"
"  0xe4, 0x43, 0x59, 0x59, 0xd9, 0xaf, 0x33, 0x33, 0x33, 0xe9, 0xee, 0x3d,\n"
"  0x81, 0x56, 0xab, 0x85, 0x28, 0x8a, 0xe8, 0xe8, 0xe8, 0x80, 0xcf, 0xe7,\n"
"  0x83, 0xcf, 0xe7, 0x83, 0x28, 0x8a, 0x50, 0x14, 0x05, 0x14, 0x45, 0xf5,\n"
"  0x4b, 0x9d, 0x1e, 0x3b, 0x76, 0x0c, 0x9b, 0xf7, 0xd5, 0x20, 0x73, 0xdc,\n"
"  0xbd, 0x28, 0xc9, 0x4f, 0x46, 0x30, 0xd2, 0x69, 0x89, 0xe6, 0x56, 0x37,\n"
"  0xae, 0xb7, 0x77, 0x82, 0x20, 0x95, 0x28, 0x4c, 0x6a, 0x11, 0x16, 0xe9,\n"
"  0x0a, 0x7e, 0xf5, 0xd4, 0x53, 0x50, 0xab, 0xd5, 0x50, 0xab, 0xd5, 0x98,\n"
"  0x30, 0x61, 0x02, 0x5e, 0xff, 0xf3, 0xeb, 0x48, 0x4b, 0x4f, 0x85, 0xd9,\n"
"  0x6c, 0xe9, 0x6a, 0xb1, 0xff, 0xaf, 0xb9, 0x2b, 0x9d, 0x5c, 0xca, 0x5d,\n"
"  0xa8, 0xbe, 0x50, 0xae, 0xd1, 0x68, 0x0f, 0x7a, 0x3c, 0x1e, 0xfb, 0x40,\n"
"  0x40, 0x9e, 0xce, 0xcc, 0xcc, 0xec, 0x91, 0xb8, 0x25, 0x49, 0x02, 0xcf,\n"
"  0xf3, 0xd0, 0xe9, 0x74, 0xa0, 0x69, 0x3a, 0x3e, 0x27, 0x12, 0x08, 0x04,\n"
"  0xe0, 0xf5, 0x7a, 0x11, 0x08, 0x04, 0x10, 0x8d, 0x46, 0xe3, 0xd4, 0x51,\n"
"  0x55, 0x55, 0x15, 0xb6, 0x7e, 0x72, 0x19, 0x99, 0x63, 0xcb, 0x50, 0x32,\n"
"  0x2a, 0x19, 0xa1, 0xb0, 0xd8, 0x09, 0xc2, 0xe9, 0x86, 0xd3, 0xd5, 0x01,\n"
"  0x59, 0x12, 0x01, 0x59, 0x84, 0x59, 0xa3, 0x40, 0xed, 0x3e, 0x8d, 0xe7,\n"
"  0x7e, 0xfb, 0x4c, 0x0f, 0xf6, 0x5e, 0xab, 0xd5, 0xa2, 0xb8, 0xb8, 0x18,\n"
"  0x7f, 0xaa, 0xa8, 0x40, 0x4e, 0x4e, 0x36, 0x12, 0x13, 0x93, 0xe2, 0xe5,\n"
"  0x7f, 0x1c, 0x4c, 0xe9, 0x24, 0xf5, 0x99, 0x33, 0x67, 0xca, 0x59, 0x56,\n"
"  0x75, 0xa4, 0xa3, 0xa3, 0xa3, 0xb1, 0x8f, 0x6b, 0x29, 0x8a, 0xd2, 0xef,\n"
"  0x58, 0x44, 0x4b, 0x4b, 0x0b, 0x5c, 0x2e, 0x17, 0x08, 0x82, 0x80, 0xd9,\n"
"  0x6c, 0x46, 0x56, 0x56, 0x56, 0xbc, 0x88, 0x4c, 0x48, 0x48, 0x88, 0x4f,\n"
"  0x46, 0x1c, 0x39, 0x72, 0x04, 0x5b, 0x3f, 0xb9, 0x8c, 0xf4, 0xe2, 0x7b,\n"
"  0x30, 0x6e, 0x54, 0x32, 0x42, 0x11, 0x11, 0x0e, 0x57, 0x07, 0x9a, 0x9d,\n"
"  0xed, 0x70, 0xb4, 0x75, 0x82, 0x50, 0x24, 0x11, 0x16, 0x1d, 0x09, 0xc9,\n"
"  0x5e, 0x85, 0x17, 0x9e, 0x7b, 0xa6, 0x0f, 0xf1, 0x20, 0xcb, 0x32, 0x38,\n"
"  0x8e, 0x43, 0x56, 0x66, 0x76, 0xcb, 0xd6, 0xad, 0x7f, 0x57, 0xec, 0xf6,\n"
"  0xa6, 0xae, 0x27, 0x3d, 0x16, 0x4c, 0xd7, 0xd3, 0x9e, 0x5e, 0xaf, 0xc7,\n"
"  0xaa, 0x5f, 0x3c, 0xa9, 0x37, 0x9b, 0x93, 0xf6, 0x58, 0x2c, 0x96, 0x99,\n"
"  0x7d, 0x80, 0xc8, 0xb2, 0xdc, 0x87, 0x5e, 0xa1, 0x69, 0x1a, 0x29, 0x29,\n"
"  0x29, 0x60, 0x18, 0x06, 0x6e, 0xb7, 0x1b, 0x4d, 0x4d, 0x4d, 0xb0, 0xdb,\n"
"  0xed, 0xf0, 0xfb, 0xfd, 0xf1, 0x7e, 0x9c, 0xe3, 0x38, 0x5c, 0xb8, 0x70,\n"
"  0x01, 0x7f, 0xdf, 0x7f, 0x19, 0x69, 0x45, 0x31, 0x10, 0x51, 0x38, 0x5d,\n"
"  0x5e, 0xb4, 0x38, 0xdb, 0xe1, 0x68, 0xf3, 0x40, 0x96, 0x22, 0x90, 0xa3,\n"
"  0x22, 0x92, 0xf5, 0x14, 0xda, 0x2f, 0x7d, 0x8a, 0xf5, 0xbf, 0x7b, 0x06,\n"
"  0x89, 0x89, 0x89, 0xe8, 0x6d, 0x7d, 0xbb, 0xdd, 0x8e, 0x8a, 0x8a, 0x8a,\n"
"  0xa3, 0xfb, 0xf7, 0xef, 0x1f, 0xf7, 0xf9, 0x89, 0x93, 0x4f, 0x55, 0x56,\n"
"  0x56, 0xc2, 0xe9, 0x74, 0x74, 0x56, 0xd8, 0xdd, 0xc0, 0xe8, 0x74, 0x3a,\n"
"  0x3c, 0xb9, 0xea, 0x09, 0x6d, 0x4e, 0xae, 0xed, 0x23, 0xbd, 0x5e, 0xff,\n"
"  0xcd, 0xee, 0xb3, 0x32, 0x74, 0x64, 0x80, 0x68, 0x26, 0x08, 0x02, 0x3a,\n"
"  0x9d, 0x0e, 0x06, 0x83, 0x21, 0x3e, 0x44, 0x20, 0x49, 0x12, 0x42, 0xa1,\n"
"  0x10, 0xa2, 0xd1, 0x28, 0x74, 0x3a, 0x1d, 0x4e, 0x9f, 0x3e, 0x8d, 0x94,\n"
"  0xc2, 0x6f, 0xa1, 0x28, 0xc7, 0x8c, 0xb0, 0x18, 0x85, 0xc3, 0xd5, 0x81,\n"
"  0x16, 0x67, 0x3b, 0x5a, 0xdb, 0x3c, 0x90, 0xa2, 0x31, 0x10, 0x34, 0x9a,\n"
"  0xbf, 0xda, 0x87, 0x3f, 0xfe, 0xfe, 0x69, 0x58, 0xad, 0xd6, 0x3e, 0x35,\n"
"  0x5d, 0x6d, 0x6d, 0x2d, 0x2a, 0x2a, 0x2a, 0xfe, 0xfb, 0xe8, 0xd1, 0xa3,\n"
"  0x8f, 0xfa, 0x7c, 0xbe, 0xa0, 0x24, 0x49, 0x1b, 0x93, 0x92, 0x92, 0xac,\n"
"  0x1c, 0xc7, 0xfd, 0x72, 0xc9, 0x92, 0x25, 0x30, 0x1a, 0x4d, 0x7d, 0xa6,\n"
"  0x8a, 0x56, 0xae, 0xfc, 0x39, 0xff, 0xe7, 0x8a, 0xd7, 0x3f, 0x34, 0x9b,\n"
"  0xcd, 0x77, 0x02, 0xf8, 0x02, 0x00, 0x48, 0x51, 0x14, 0x03, 0x03, 0x65,\n"
"  0x82, 0x48, 0x24, 0x82, 0xd6, 0xd6, 0x56, 0x04, 0x83, 0xc1, 0xf8, 0x4c,\n"
"  0x89, 0xc9, 0x64, 0x82, 0x5e, 0xaf, 0x07, 0x41, 0x10, 0x48, 0x4c, 0x4c,\n"
"  0x44, 0x54, 0x70, 0xc1, 0xe3, 0x0b, 0xc0, 0xe9, 0xea, 0x40, 0xeb, 0xf5,\n"
"  0x76, 0xb4, 0x5e, 0x6f, 0x8f, 0x83, 0x48, 0xd2, 0x51, 0x68, 0xba, 0x70,\n"
"  0x00, 0x1b, 0x5f, 0xf8, 0x05, 0x72, 0x73, 0x73, 0x7b, 0xac, 0x1d, 0x0c,\n"
"  0x06, 0xf1, 0xc5, 0x17, 0x5f, 0x60, 0xed, 0xda, 0xb5, 0xbf, 0xd3, 0xeb,\n"
"  0xf5, 0x0f, 0xfb, 0x7c, 0xbe, 0x60, 0x2c, 0xd9, 0x3c, 0xf0, 0xc0, 0x03,\n"
"  0xbf, 0xda, 0xf1, 0xde, 0xce, 0xb7, 0x77, 0xef, 0xda, 0x0d, 0xbf, 0xe0,\n"
"  0x8f, 0x5b, 0x86, 0x24, 0x48, 0x5c, 0xbe, 0x7c, 0x19, 0x04, 0x01, 0x3c,\n"
"  0xf4, 0xf0, 0x52, 0xde, 0xef, 0xf7, 0xaf, 0x8b, 0xcd, 0xc2, 0x90, 0x92,\n"
"  0x24, 0x0d, 0x78, 0x6b, 0xf2, 0x3c, 0x8f, 0xe4, 0xe4, 0x64, 0xa8, 0x54,\n"
"  0x2a, 0x84, 0x42, 0x21, 0x74, 0x74, 0x74, 0xf4, 0x18, 0x7d, 0x9a, 0x35,\n"
"  0x6b, 0x16, 0xd0, 0xf0, 0x31, 0xea, 0xea, 0xae, 0xc1, 0xde, 0xea, 0x46,\n"
"  0xcb, 0xf5, 0x76, 0x44, 0xbb, 0x40, 0x98, 0xb4, 0x34, 0x5c, 0x5f, 0x9f,\n"
"  0xc4, 0xba, 0x5f, 0x3d, 0x82, 0x31, 0x63, 0xc6, 0xf4, 0x58, 0xd7, 0xe7,\n"
"  0xf3, 0xe1, 0xc0, 0x81, 0x03, 0xa1, 0x55, 0xab, 0x56, 0x3d, 0x7c, 0xf4,\n"
"  0xe8, 0xd1, 0x67, 0x2b, 0x2b, 0x2b, 0x7b, 0xdc, 0x65, 0x7f, 0xf9, 0xcb,\n"
"  0x5f, 0x94, 0xec, 0xec, 0xec, 0x47, 0x36, 0x6f, 0xde, 0xba, 0x7b, 0xef,\n"
"  0x9e, 0x3d, 0x08, 0x06, 0x03, 0xe0, 0xd4, 0x6a, 0xec, 0xdf, 0xff, 0x29,\n"
"  0x5e, 0x7e, 0x69, 0xe3, 0xfb, 0xa7, 0x4e, 0x9d, 0x46, 0x7a, 0x7a, 0x1a,\n"
"  0x4c, 0x26, 0xd3, 0x98, 0xd8, 0x20, 0x01, 0xb9, 0x73, 0xe7, 0xce, 0xbf,\n"
"  0x35, 0x36, 0x36, 0x0e, 0x4a, 0x03, 0x69, 0x34, 0x1a, 0x18, 0x8d, 0x46,\n"
"  0x18, 0x0c, 0x86, 0x1e, 0xcf, 0xce, 0x3c, 0xcf, 0x63, 0xd5, 0xca, 0x9f,\n"
"  0x22, 0x78, 0xe9, 0x7f, 0xa0, 0x84, 0xda, 0xa1, 0x44, 0x45, 0xc8, 0x51,\n"
"  0x11, 0x06, 0x9e, 0x82, 0xcf, 0x7e, 0x0e, 0xab, 0x7e, 0x38, 0x17, 0x93,\n"
"  0x26, 0x4d, 0xea, 0x51, 0x4c, 0xba, 0x5c, 0x2e, 0xec, 0xd8, 0xb1, 0xc3,\n"
"  0xf1, 0xe2, 0x8b, 0x2f, 0x7e, 0xcb, 0xe1, 0x70, 0x6c, 0x1d, 0x88, 0xe3,\n"
"  0x3a, 0x7f, 0xfe, 0x7c, 0xd4, 0x64, 0x32, 0x95, 0xff, 0xe7, 0xeb, 0xff,\n"
"  0x75, 0xec, 0xf0, 0xa1, 0x43, 0x08, 0x87, 0xc3, 0xc8, 0xb6, 0x65, 0x43,\n"
"  0x14, 0x23, 0x65, 0x26, 0x93, 0x09, 0x3e, 0x9f, 0x00, 0x41, 0x10, 0x9a,\n"
"  0x63, 0x2c, 0x3d, 0xd1, 0xc5, 0x0c, 0xfe, 0xeb, 0xaa, 0x55, 0xab, 0x36,\n"
"  0x8e, 0x1f, 0x3f, 0x9e, 0xbd, 0x91, 0xf7, 0x40, 0x8f, 0xc7, 0x83, 0x75,\n"
"  0x2f, 0xbe, 0x0a, 0x2a, 0x65, 0x32, 0x40, 0x73, 0xf0, 0x39, 0x2e, 0xe3,\n"
"  0x07, 0x73, 0xc6, 0x63, 0xfe, 0xfc, 0xf9, 0x3d, 0x82, 0xba, 0xa5, 0xa5,\n"
"  0x05, 0xdb, 0xb6, 0x6d, 0xfb, 0x6a, 0xcf, 0x9e, 0x3d, 0xf3, 0xae, 0x5d,\n"
"  0xbb, 0xd6, 0x30, 0x9c, 0xb5, 0xad, 0x56, 0xab, 0xc9, 0x2f, 0xf8, 0x3f,\n"
"  0xfb, 0xf5, 0x9a, 0xd5, 0x63, 0xbe, 0x31, 0x75, 0x1a, 0x24, 0xa9, 0xb3,\n"
"  0x7d, 0x78, 0xf7, 0xdd, 0xed, 0xf8, 0x70, 0xf7, 0x47, 0xdf, 0x6f, 0x6b,\n"
"  0x6b, 0xdb, 0x82, 0xee, 0x4d, 0x55, 0x5a, 0x5a, 0x5a, 0xe1, 0xec, 0xd9,\n"
"  0xb3, 0x5f, 0x9f, 0x35, 0x6b, 0xd6, 0x9d, 0x36, 0x9b, 0x6d, 0xc4, 0xef,\n"
"  0x80, 0x3e, 0x9f, 0x0f, 0x87, 0x0f, 0x1f, 0x86, 0xdb, 0xed, 0xc6, 0xc4,\n"
"  0x89, 0x13, 0x31, 0x73, 0xe6, 0xcc, 0xf8, 0xc5, 0x29, 0x8a, 0x22, 0x6a,\n"
"  0x6b, 0x6b, 0xb1, 0x69, 0xd3, 0xa6, 0x9d, 0x8d, 0x8d, 0x8d, 0x0f, 0x7d,\n"
"  0xfe, 0xf9, 0xe7, 0x81, 0x91, 0xac, 0x6d, 0xb1, 0x58, 0x52, 0x3d, 0x1e,\n"
"  0xcf, 0xce, 0x07, 0x1e, 0xbc, 0xbf, 0x34, 0x21, 0x41, 0x8f, 0xf3, 0x5f,\n"
"  0x5d, 0x90, 0xcf, 0x9c, 0x39, 0xbb, 0xee, 0xdc, 0xb9, 0x73, 0xcf, 0xda,\n"
"  0x6c, 0x36, 0xa0, 0x77, 0x77, 0x28, 0x49, 0x12, 0xb2, 0xb2, 0xb2, 0xe6,\n"
"  0xcc, 0x99, 0x33, 0x67, 0xcd, 0xd4, 0xa9, 0x53, 0xa7, 0xe7, 0xe5, 0xe5,\n"
"  0x0d, 0xfa, 0xc8, 0x33, 0x90, 0xc4, 0x38, 0xb1, 0x18, 0x67, 0x75, 0xfa,\n"
"  0xf4, 0x69, 0xa5, 0xa2, 0xa2, 0xe2, 0x85, 0xaa, 0xaa, 0xaa, 0xe7, 0x6e,\n"
"  0x74, 0x22, 0xe2, 0xd8, 0xb1, 0x63, 0xc4, 0xf2, 0xe5, 0xcb, 0xa7, 0xb7,\n"
"  0xb5, 0xb5, 0x65, 0x9b, 0xcd, 0xe6, 0x83, 0x17, 0x2e, 0x5c, 0x68, 0xea,\n"
"  0xbe, 0x56, 0xbf, 0xdd, 0xa1, 0x20, 0x08, 0x28, 0x29, 0x29, 0x29, 0xb1,\n"
"  0x58, 0x2c, 0x3f, 0x9c, 0x3d, 0x7b, 0xf6, 0xe2, 0xfc, 0xfc, 0x7c, 0x6b,\n"
"  0x5a, 0x5a, 0x1a, 0x86, 0x3b, 0x78, 0x1f, 0xa3, 0x8b, 0x7c, 0x3e, 0x1f,\n"
"  0x3e, 0xfe, 0xf8, 0x63, 0xff, 0x86, 0x0d, 0x1b, 0x96, 0xd9, 0xed, 0xf6,\n"
"  0x1d, 0x37, 0x72, 0x28, 0xc3, 0x1e, 0xf3, 0x18, 0xea, 0x83, 0xc7, 0x1f,\n"
"  0x7f, 0x9c, 0x3c, 0x70, 0xe0, 0xc0, 0x94, 0x60, 0x30, 0x78, 0xdf, 0x82,\n"
"  0x05, 0x0b, 0xee, 0xca, 0xc8, 0xc8, 0x28, 0xb5, 0x5a, 0xad, 0xea, 0xc4,\n"
"  0xc4, 0x44, 0xe8, 0xf5, 0xfa, 0x7e, 0xeb, 0x2e, 0x8e, 0xe3, 0x10, 0x0c,\n"
"  0x06, 0x51, 0x59, 0x59, 0x79, 0x65, 0xc7, 0x8e, 0x1d, 0x8b, 0xea, 0xeb,\n"
"  0xeb, 0x2f, 0xdc, 0xee, 0x81, 0x81, 0x11, 0xbd, 0x2b, 0x47, 0xa3, 0x51,\n"
"  0x7c, 0xef, 0x7b, 0xdf, 0x63, 0xcf, 0x9d, 0x3b, 0x57, 0x24, 0x08, 0x42,\n"
"  0x71, 0x34, 0x1a, 0xbd, 0x63, 0xc6, 0x8c, 0x19, 0xb6, 0x9c, 0x9c, 0x9c,\n"
"  0x74, 0x95, 0x4a, 0x95, 0xcc, 0xf3, 0xbc, 0x91, 0x61, 0x18, 0x2d, 0x45,\n"
"  0x51, 0xec, 0xe1, 0xc3, 0x87, 0x77, 0x5c, 0xbc, 0x78, 0xf1, 0xd1, 0x9a,\n"
"  0x9a, 0x9a, 0x8e, 0x7f, 0xc6, 0xe4, 0xc3, 0xff, 0x02, 0x51, 0x62, 0x90,\n"
"  0xe9, 0xcf, 0x59, 0x64, 0x51, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e,\n"
"  0x44, 0xae, 0x42, 0x60, 0x82\n"
"};\n"
"\n"
"void File_computer_png(struct WebServer *Web)\n"
"{\n"
"    WS_Header(Web,\"Content-Type: image/png\");\n"
"    WS_WriteWhole(Web,computer_png,sizeof(computer_png));\n"
"}\n"
"</div>\n"
"\n"
"<p>This is the computer.png file. It has been encoded as a hex dump of\n"
"the binary computer.png file. This was done with the\n"
"<span class='coderef'>xxd -i computer.png &gt; computer.c</span> Linux\n"
"command. <span class='coderef'>xxd</span> is a hex dump program that\n"
"reads in a file and makes a hex dump. This -i has it make C code and\n"
"that output is redirected into a file. That file was opened and copied\n"
"into the source.</p>\n"
"\n"
"<p>The <span class='coderef'>File_computer_png()</span> function is a\n"
"standard callback for this file. It includes a call to\n"
"<span class='coderef'>WS_Header()</span> which adds a HTTP\n"
"header to the out going reply. In this case it is adding\n"
"setting \"Content-Type\" to \"image/png\".</p>\n"
"\n"
"<p>The <span class='coderef'>WS_Header()</span> function can be used to\n"
"set any http header, but can only be called before any write has been\n"
"done (WS_WriteWhole() for example).</p>\n"
"\n"
"<p>The "PRODUCTNAME" web server only\n"
"sets \"Content-Length\", \"ETag\", \"Transfer-Encoding\",\n"
"and \"Set-Cookie\" headers.</p>\n"
"\n"
"<p>Next the whole image is sent using\n"
"<span class='coderef'>WS_WriteWhole()</span> as has been done\n"
"before.</p>\n"
"";

void File_Doc_Graphics(struct WebServer *Web)
{
    WS_WriteChunk(Web,m_GraphicsHTML,sizeof(m_GraphicsHTML)-1);
    OutputListOfExampleFiles(Web,e_ExampleCode_Graphics);
    WS_WriteChunk(Web,m_GraphicsHTML2,sizeof(m_GraphicsHTML2)-1);
}
