/*******************************************************************************
 * FILENAME: HelloWorld.c
 *
 * PROJECT:
 *    Bitty HTTP
 *
 * FILE DESCRIPTION:
 *    
 *
 * COPYRIGHT:
 *    Copyright (c) 2019 Paul Hutchinson
 *
 *    Permission is hereby granted, free of charge, to any person obtaining a copy
 *    of this software and associated documentation files (the "Software"), to deal
 *    in the Software without restriction, including without limitation the rights
 *    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *    copies of the Software, and to permit persons to whom the Software is
 *    furnished to do so, subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included in all
 *    copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *    SOFTWARE.
 *
 ******************************************************************************/

/*** HEADER FILES TO INCLUDE  ***/
#include "CodeExamples.h"
#include "Pages/Pages.h"
#include "Common/Headers.h"

/*** DEFINES                  ***/

/*** MACROS                   ***/

/*** TYPE DEFINITIONS         ***/

/*** FUNCTION PROTOTYPES      ***/

/*** VARIABLE DEFINITIONS     ***/

const char m_HelloWorldHTML[]=
"<h1><span>1</span>Hello World</h1>\n"
"<p>This example will cover a basic hello world style web site. It will go "
"over initializing the web server, setting up your main loop, call backs "
"from the web server for pages, and sending the requested page.</p>"
""
"<h2>Files</h2>";

const char m_HelloWorldHTML2[]=
"<h2>main.c</h2>"
"<p>We start the main.c file with includes.</p>\n"
"\n"
"<div class='code'>"
"#include \"main.h\"\n"
"#include \"WebServer.h\"\n"
"#include &lt;stdint.h&gt;\n"
"#include &lt;stdio.h&gt;\n"
"\n"
"#include &lt;unistd.h&gt; // usleep()\n"
"</div>\n"
"\n"
"<p>We include the basic sockets, web server, main it's self, and some "
"standard includes.</p>\n"
"\n"
"<p>We also include unistd.h because we are going to use a usleep() in the "
"main loop instead of waiting for signals or file handles. On a computer "
"this is very waste full but in an embedded system we don't normally wait "
"and just run full out. We use the usleep() in the example because it is a "
"simple one line, later we will get into waiting on a socket handle using a "
"select().</p>\n"
"\n"
"<p>Next we add the main() function.</p>\n"
"\n"
"<div class='code'>"
"bool g_Quit;\n"
"\n"
"int main(void)\n"
"{\n"
"    t_ElapsedTime Waiting2End;\n"
"\n"
"    SocketsCon_InitSocketConSystem();\n"
"    WS_Init();\n"
"\n"
"    if(!WS_Start(3000))\n"
"    {\n"
"        printf(\"Failed to start web server\\n\");\n"
"        return 1;\n"
"    }\n"
"\n"
"    printf(\"Waiting for connections on port 3000\\n\");\n"
"\n"
"    g_Quit=false;\n"
"    while(!g_Quit)\n"
"    {\n"
"        WS_Tick();\n"
"        usleep(1000);\n"
"    }\n"
"\n"
"    printf(\"Quiting...\\n\");\n"
"\n"
"    /* Run the web server for a while so we can send any \"finished\" page */\n"
"    Waiting2End=ReadElapsedClock();\n"
"    while(ReadElapsedClock()-Waiting2End&gt;3)\n"
"        WS_Tick();\n"
"\n"
"    WS_Shutdown();\n"
"    SocketsCon_ShutdownSocketConSystem();\n"
"\n"
"    return 0;\n"
"}\n"
"</div>"
"\n"
"<p>We have a global variable <span class='coderef'>g_Quit</span> that is set "
"to true to exit the "
"program.</p>\n"
"\n"
"<p>We start by calling the "
"<span class='coderef'>SocketsCon_InitSocketConSystem()</span> function. "
"This will initialize the sockets. In the case of basic Berkeley sockets "
"this would do nothing. If you are using SSL it would init the SSL library, "
"and on an embedded system this could init the whole TCP/IP stack.</p>\n"
"\n"
"<p>The next thing to do is init and setup the web server. We call "
"<span class='coderef'> WS_Init()</span> and then "
"<span class='coderef'>WS_Start()</span> with the port to listen on. "
"This will init the main socket and start it listening for "
"incoming connections.</p>\n"
"\n"
"<p>The printf() has be added to tell the user what port the web server is "
"listening on.</p>\n"
"\n"
"<p>We then enter the main loop. In it we call the function "
"<span class='coderef'>WS_Tick()</span>. "
"<span class='coderef'>WS_Tick()</span> runs the web server, this must be "
"called regularly.</p>\n"
"\n"
"<p>Next we do the <span class='coderef'>usleep()</span> so we don't pin "
"the processor. This maybe replace with a "
"<span class='coderef'>select()</span> call to wait for traffic on the "
"sockets, or removed completely.</p>\n"
"\n"
"<p>After the main loop we have a second loop. This is used to keep the "
"web server running to finish sending any CSS, graphics, or other things "
"if a web page quits. This is needed because if we just quit we will close "
"the socket and hang up on the browser before it can get any more needed "
"data.</p>\n"
"\n"
"<p>We just wait for 2-3 seconds running the tick function.</p>\n"
"\n"
"<p>Finally we call "
"<span class='coderef'>SocketsCon_ShutdownSocketConSystem()</span> to free "
"anything that was allocated in "
"<span class='coderef'>SocketsCon_InitSocketConSystem()</span>.</p>\n"
"\n"
"<p>Last we have a utility function:</p>\n"
"\n"
"<div class='code'>"
"uint32_t ReadElapsedClock(void)\n"
"{\n"
"    time_t Current; // The current time\n"
"\n"
"    Current=time(NULL);\n"
"\n"
"    return (uint32_t)Current;\n"
"}\n"
"</div>"
"\n"
"<p>This is simple function for getting the number of seconds that have "
"passed. This does not have to be real time as it is only used for delta "
"timing. This example just gets the current real time clock value.</p>\n"
"\n"
"<h2>Options.h</h2>\n"
"<p>This file has defines in it that are used to customize the web server.</p>\n"
"\n"
"<div class='code'>"
"#define DOCVER                              \"1.0.0.0\"\n"
"\n"
"#define WS_OPT_MAX_CONNECTIONS              16      // The max number of connections we can handle at the same time (this will include buffers needed for each connection)\n"
"#define WS_OPT_ARG_MEMORY_SIZE              100     // The memory block to use to store the cookies, get args, and post args\n"
"#define WS_SECONDS_UNTIL_CONNECTION_RELEASE 10      // How many seconds to wait after a connection stops sending to us before we hang up\n"
"#define WS_LINE_BUFFER_SIZE                 256     // The max number of bytes we can handle a single header line can be (including the GET line).  This is normally in the order of 16K - 128K (we default to a lot less)\n"
"</div>"
"\n"
"<p>There is a <span class='coderef'>DOCVER</span> define which is used by "
"the web server for when to let the browser know to use it's cached version "
"or not. This is the ETAG, and if the version number in this define "
"is the same then the browser will use the cached version, and if not it "
"will get a new copy.</p>\n"
"\n"
"<p>The current string is a version number, however this could be any "
"string that you change with every release. Something like "
"<span class='coderef'>_DATE_ _TIME_</span> "
"would work as long as you rebuild the WebServer.c file.</p>\n"
"\n"
"<p>The next set of defines are used to customize the web server. Most of "
"these are needed because in embedded code the amount of RAM is very "
"limited and these help you control how much memory the web server will "
"use.</p>\n"
"\n"
"<table class='FnDescTable'>"
"<tr><td>WS_OPT_MAX_CONNECTIONS</td><td>The max number of connections we can handle at the same time (this will include buffers needed for each connection)</td></tr>\n"
"<tr><td>WS_OPT_ARG_MEMORY_SIZE</td><td>The memory block to use to store the cookies, get args, and post args</td></tr>\n"
"<tr><td>WS_SECONDS_UNTIL_CONNECTION_RELEASE</td><td>How many seconds to wait after a connection stops sending to us before we hang up</td></tr>\n"
"<tr><td>WS_LINE_BUFFER_SIZE</td><td>The max number of bytes we can handle a single header line can be (including the GET line). This is normally in the order of 16K - 128K (we default to a lot less)</td></tr>\n"
"</table>\n"
"\n"
"<h2>FileServer.c</h2>\n"
"<p>This file has the pages we support in it. It also include the functions \n"
"that the web server will call to get info or the contents of the \n"
"requested web page.</p>\n"
"\n"
"<p>At the top of the file we have the includes.</p>\n"
"\n"
"<div class='code'>"
"#include \"../../WebServer.h\"\n"
"#include \"FileServer.h\"\n"
"#include &lt;stdbool.h&gt;\n"
"#include &lt;string.h&gt;\n"
"#include &lt;stdio.h&gt;\n"
"</div>\n"
"\n"
"<p>Next we have a new structure that we use to describe a file.</p>\n"
"\n"
"<div class='code'>"
"struct FileInfo\n"
"{\n"
"    const char *Filename;   // With Path\n"
"    bool Dynamic;\n"
"    const char **Cookies;\n"
"    const char **Gets;\n"
"    const char **Posts;\n"
"    void (*WriteFile)(struct WebServer *Web);\n"
"};\n"
"</div>\n"
"\n"
"<p>There is nothing saying you have to use this structure as parts of it \n"
"are copied into a <span class='coderef'>struct WSPageProp</span> structure.\n"
"This just makes it convenient.</p>\n"
"\n"
"<p>The first member of this structure is\n"
"<span class='coderef'>Filename</span>. This is the file name of the page.\n"
"This need not be a real file on the disk. This is just strcmp()ed with\n"
"the URL path. For example\n"
"\"http://example.com/path/file.html\" the filename would be\n"
"\"/path/file.html\".</p>\n"
"\n"
"<p><span class='coderef'>Dynamic</span> is if this file is dynamic or\n"
"static. For a static file the ETAG will be set to\n"
"<span class='coderef'>DOCVER</span> so it will not be sent over and over.\n"
"For dynamic the page will not be cached by the browser and it will request\n"
"a new copy every time the file is loaded (the file will not be cached).</p>\n"
"\n"
"<p>You should set the dynamic to false for any page that never changes.\n"
"Things like graphics, css files should be marked as static. Pages where\n"
"the content changes depending on what is sent in or where external objects\n"
"effect the page content (things like time) should be marked as dynamic.</p>\n"
"\n"
"<p>'Cookies' is a list of the cookies you want to be able to read on\n"
"the page. You must list any cookies (or GETs, or POSTs vars) you\n"
"want before the page is requested so the system knowns what cookies\n"
"to store. This is so we don't need to store the names of cookies in\n"
"RAM. These are stored in const space. The system will not load any\n"
"cookies that are not listed in this.</p>\n"
"\n"
"<p>The cookies are a list of strings followed by a NULL entry. So for\n"
"example:</p>\n"
"\n"
"<div class='code'>"
"const char *MyCookies[]=\n"
"{\n"
"    \"CookieA\",\n"
"    \"CookieB\",\n"
"    NULL\n"
"}\n"
"</div>\n"
"\n"
"<p><span class='coderef'>Gets</span> is the list of GET vars you want\n"
"to be able to read on the page. These work the same as\n"
"<span class='coderef'>Cookies</span>.</p>\n"
"\n"
"<p><span class='coderef'>Posts</span> is the list of POST vars you want\n"
"to be able to read on the page. These work the same as\n"
"<span class='coderef'>Cookies</span>.</p>\n"
"\n"
"<p><span class='coderef'>WriteFile</span> is a pointer to a function that\n"
"will be used to output the contents of the page. This will be called\n"
"from <span class='coderef'>FS_SendFile()</span>.</p>\n"
"\n"
"<p>Next we have the prototype and the list of \"files\" we support.</p>\n"
"\n"
"<div class='code'>"
"void File_Root(struct WebServer *Web);\n"
"\n"
"struct FileInfo m_Files[]=\n"
"{\n"
"    /* Filename, Dynamic, Cookies, Gets, Posts, Callback */\n"
"    {\"/\",false,NULL,NULL,NULL,File_Root},\n"
"};\n"
"</div>\n"
"\n"
"<p>The <span class='coderef'>File_Root()</span> is a normal prototype.\n"
"The <span class='coderef'>m_Files</span> array is a list\n"
"of all the different \"files\" we support and what properties apply\n"
"to it.</p>\n"
"\n"
"<p>In this case we only have 1 \"file\" named \"/\" (what the web browser\n"
"will request if you do not provide a path or filename in the URL).</p>\n"
"\n"
"<div class='code'>"
"bool FS_GetFileProperties(const char *Filename,struct WSPageProp *PageProp)\n"
"{\n"
"    int r;\n"
"\n"
"    for(r=0;r&lt;sizeof(m_Files)/sizeof(struct FileInfo);r++)\n"
"    {\n"
"        if(strcmp(Filename,m_Files[r].Filename)==0)\n"
"        {\n"
"            PageProp-&gt;FileID=(uintptr_t)&m_Files[r];\n"
"            PageProp-&gt;DynamicFile=m_Files[r].Dynamic;\n"
"            PageProp-&gt;Cookies=m_Files[r].Cookies;\n"
"            PageProp-&gt;Gets=m_Files[r].Gets;\n"
"            PageProp-&gt;Posts=m_Files[r].Posts;\n"
"            return true;\n"
"        }\n"
"    }\n"
"    return false;\n"
"}\n"
"</div>\n"
"\n"
"<p>This function is called from the web server. It collects info about a\n"
"file that the web browser is requesting. It loops though all the\n"
"available \"files\" and if there is a match (using the strcmp()) it will\n"
"fill in the 'PageProp' structure with info from the array and return\n"
"true (meaning we know this page).</p>\n"
"\n"
"<p>If this function returns false then the system will generate a\n"
"404 error status and sent that to the browser.</p>\n"
"\n"
"<p>If you want to overrule the default 404 error page (which is VERY\n"
"basic) then you always return true from this function but point\n"
"the FileID to an 404 error page you provide.</p>\n"
"\n"
"<p>The next function in the file is the\n"
" <span class='coderef'>FS_SendFile()</span> function:</p>\n"
"\n"
"<div class='code'>"
"void FS_SendFile(struct WebServer *Web,uintptr_t FileID)\n"
"{\n"
"    struct FileInfo *File=(struct FileInfo *)FileID;\n"
"\n"
"    /* Not needed but I always check... */\n"
"    if(File==NULL)\n"
"        return;\n"
"\n"
"    File-&gt;WriteFile(Web);\n"
"}\n"
"</div>\n"
"\n"
"<p>This function is called from the web server after all the headers\n"
"have been processed and it is time to send the content for a page.\n"
"It includes a handle to the web server context and the\n"
"<span class='coderef'>FileID</span> that was filled in the page prop\n"
"FileID. It is big enough to store a pointer, but is an int.</p>\n"
"\n"
"<p>The example is using FileID as a pointer into the\n"
"<span class='coderef'>m_Files</span> array,\n"
"but it could have been written to have the index into\n"
"<span class='coderef'>m_Files</span>.</p>\n"
"\n"
"<p>It calls the function to send the page content from\n"
"<span class='coderef'>m_Files</span>.</p>\n"
"\n"
"<p>The last part of the file is the \"root\" page:</p>\n"
"\n"
"<div class='code'>"
"const char HelloWorldHTML[]=\n"
"\"&lt;html&gt;\"\n"
"    \"&lt;body&gt;\"\n"
"        \"Hello World\"\n"
"    \"&lt;/body&gt;\"\n"
"\"&lt;/html&gt;\";\n"
"\n"
"void File_Root(struct WebServer *Web)\n"
"{\n"
"    WS_WriteWhole(Web,HelloWorldHTML,sizeof(HelloWorldHTML)-1);\n"
"}\n"
"</div>\n"
"\n"
"<p>This has the HTML in a global const string, and there is the\n"
"function that will be called for this page. The function just\n"
"sends the whole string using the\n"
"<span class='coderef'>WS_WriteWhole()</span> function (send static data).\n"
"</p>\n"
"";

void File_Doc_HelloWorld(struct WebServer *Web)
{
    WS_WriteChunk(Web,m_HelloWorldHTML,sizeof(m_HelloWorldHTML)-1);
    OutputListOfExampleFiles(Web,e_ExampleCode_HelloWorld);
    WS_WriteChunk(Web,m_HelloWorldHTML2,sizeof(m_HelloWorldHTML2)-1);
}
